// -*- C++ -*-
/*!
 * @file  VersatileOverheadManager.h
 * @brief State management
 * @date  $Date$
 *
 * @author 株式会社 東日本計算センター
 *
 * New BSD
 *
 * $Id$
 */

#ifndef VERSATILEOVERHEADMANAGER_H
#define VERSATILEOVERHEADMANAGER_H

#include <rtm/idl/BasicDataTypeSkel.h>
#include <rtm/idl/ExtendedDataTypesSkel.h>
#include <rtm/idl/InterfaceDataTypesSkel.h>

//add
#include "local_basic_type.h"
#include "VersatileOverheadSystem.h"

// Service implementation headers
// <rtc-template block="service_impl_h">
#include "VersatileOverheadManagerSVC_impl.h"

// </rtc-template>

// Service Consumer stub headers
// <rtc-template block="consumer_stub_h">
#include "VersatileOverheadGuiStub.h"
#include "AdditinalDataDBControlStub.h"
#include "TileGeneratorStub.h"
#include "MapDataDBControlStub.h"
#include "MapImageSelectorStub.h"
#include "CrawlerViewImagSynthesisStub.h"

/*====================================================
	マクロ定義
 ===================================================*/
//マトリクス用
#define MGR_MODE_NON		0xFFFF		//モード変化なし

//マトリクストリガ
enum MATRIX_TRIGGER_NUM{
	TRG_INIT_SUCCESS = 0,				//起動処理正常終了
	TRG_SHOOT_LIST_CREATE_SUCCESS,		//撮影計画リスト作成正常終了
	TRG_SHOOT_LIST_CREATE_ERROR,		//撮影計画リスト作成異常終了
	TRG_SYNTHE_LIST_CREATE_SUCCESS,		//合成計画リスト作成正常終了
	TRG_SYNTHE_LIST_CREATE_ERROR,		//合成計画リスト作成異常終了
	TRG_DB_REG_SUCCESS,					//DB登録正常終了
	TRG_DB_REG_ERROR,					//DB登録異常終了
	TRG_TILE_GENE_SUCCESS,				//タイル生成正常終了
	TRG_TILE_GENE_ERROR,				//タイル生成異常終了
	TRG_MAP_IMAGE_DISP_SUCCESS,			//地図画像表示正常終了
	TRG_MAP_IMAGE_DISP_ERROR,			//地図画像表示異常終了
	TRG_MAP_IMAGE_OPE_SUCCESS,			//地図操作正常終了
	TRG_MAP_IMAGE_OPE_ERROR,			//地図操作異常終了
	TRG_CRAWLER_VIEW_DISP_SUCCESS,		//Crawler View画像表示正常終了
	TRG_CRAWLER_VIEW_DISP_ERROR,		//Crawler View操作異常終了
	TRG_CRAWLER_VIEW_OPE_SUCCESS,		//Crawler View操作正常終了
	TRG_CRAWLER_VIEW_OPE_ERROR,			//Crawler View操作異常終了
	TRG_SYNTHE_LIST_DEL_SUCCESS,		//合成計画リスト削除正常終了
	TRG_SYNTHE_LIST_DEL_ERROR,			//合成計画リスト削除異常終了
	TRG_DB_REGIST_KEY,					//DB登録キー押下
	TRG_TILE_GENERATE_KEY,				//タイル生成キー押下
	TRG_DISP_UPDATE_KEY,				//表示更新キー押下
	TRG_SYNTHE_LIST_DEL_KEY,			//合成計画リスト削除キー押下
	TRG_ARROW_KEY,						//十字キー押下
	TRG_ZOOM_KEY,						//ズームレベル設定キー押下
	TRG_MAP_CHANGE,						//地図切り替えキー押下
	TRG_MAX,
};

#define TRG_NON			0xFFFF			//トリガなし

//マトリクス動作要求
enum MATRIX_ACT_NUM{
	ACT_DRONE_SHOOT_LIST_READ = 0,		//ドローン用撮影計画リスト読み込み開始
	ACT_CRAWLER_SHOOT_LIST_READ,		//Crawler用撮影計画リスト読み込み開始
	ACT_SYNTHE_LIST_READ,				//合成計画リスト読み込み開始
	ACT_ALLLIST_READ_END,				//全リスト読み込み完了
	ACT_DB_REGIST_START,				//DB登録開始
	ACT_DB_REGIST_END,					//DB登録完了
	ACT_TILE_GENERATE_START,			//タイル生成開始
	ACT_TILE_GENERATE_END,				//タイル生成完了
	ACT_DISP_UPDATE_START,				//表示更新開始
	ACT_DISP_UPDATE_END,				//表示更新完了
	ACT_IMAGE_OPE_END,					//画像操作完了
	ACT_SYNTHE_LIST_DEL_START,			//合成計画リスト削除開始
	ACT_SYNTHE_LIST_DEL_END,			//合成計画リスト削除完了
	ACT_ARROW_OPE_START,				//十字キー操作開始
	ACT_ZOOM_ADJ_START,					//ズームレベル調整開始
	ACT_MAP_CHANGE_START,				//地図切り替え開始
	ACT_INIT_WARNING_MES,				//起動処理中警告メッセージ処理
	ACT_RUN_WARNING_MES,				//動作中警告メッセージ処理
	ACT_ERROR_MES,						//エラー通知
	ACT_MAX,
};

#define	ACT_NON			0xFFFF			//アクションなし

//メイン画面更新状態
enum MAINDISP_UPDATE_STS{
  MAINDISP_UPDATE_STS_MAP_SCROLL = 0,	//スクロールにより地図画像更新中
  MAINDISP_UPDATE_STS_MAP_ZOOM,			//Zoomレベル更新中
  MAINDISP_UPDATE_STS_MAP_CHG,			//地図切り替え中
  MAINDISP_UPDATE_STS_MAX,
};

#define MAINDISP_UPDATE_STS_NON		0xFFFF		//メイン画面更新終了

//サブ画面更新状態
enum SUBDISP_UPDATE_STS{
  SUBDISP_UPDATE_STS_SLIDE = 0,			//スライド切り替え中
  SUBDISP_UPDATE_STS_MAX,
};

#define SUBDISP_UPDATE_STS_NON		0xFFFF		//サブ画面更新終了

//表示更新要求
#define REQ_DISP_UPDATE_NON			0x0000
#define REQ_DISP_UPDATE_MAIN		0x0001		//メイン画面更新要求
#define REQ_DISP_UPDATE_SUB			0x0002		//サブ画面更新要求

#define MASK_REQ_DISP_UPDATE_MAIN	0xFFFE		//メイン画面更新要求消去
#define MASK_REQ_DISP_UPDATE_SUB	0xFFFD		//サブ画面更新要求消去

//モジュールID
//enum MODULE_ID{
//	MODULE_ID_ADD_DB = 0,
//	MODULE_ID_TILE_GENERATE,
//	MODULE_ID_MAP_DB,
//	MODULE_ID_MAP_IMAGE_SEL,
//	MODULE_ID_CRAWLER_VIEW,
//	MODULE_ID_MAX,
//};

//メッセージ
#define ERROR_MESSEGE_1	"[ERROR MESSEGE]This request can not be accepted because it is in the start process"
#define ERROR_MESSEGE_2	"[ERROR MESSEGE]This request can not be accepted because it is in the process"
#define ERROR_MESSEGE_3	"[ERROR MESSEGE]This request can not be accepted because of an error accurred"

/*====================================================
struct定義
===================================================*/
struct TileGenerateKeyParam_st{
	uword_type ulGenerateMode;
	uword_type uwRobotCategory;
	uword_type uwGroupId;
	double_type dStartLatitude;
	double_type dStartLongitude;
	double_type dEndLatitude;
	double_type dEndLongitude;
	uword_type uwZoomlevel;
};

struct DispUpDate_st{
	uword_type uwMainViewGroupId;
	uword_type uwSubViewSelect;
	uword_type uwSubViewGroupId;
};

struct NoticeConv_st{
	uhword_type	uhwNotice;		//完了通知
	uhword_type	uhwTrigger;		//内部トリガ
};

// </rtc-template>

// Service Consumer stub headers
// <rtc-template block="port_stub_h">
// </rtc-template>

using namespace RTC;

#include <rtm/Manager.h>
#include <rtm/DataFlowComponentBase.h>
#include <rtm/CorbaPort.h>
#include <rtm/DataInPort.h>
#include <rtm/DataOutPort.h>

/*!
 * @class VersatileOverheadManager
 * @brief State management
 *
 * 別紙"機能仕様書_多目的俯瞰画像合成マネージャRTC.docx"参照
 *
 * 別紙"機能仕様書_多目的俯瞰画像合成マネージャRTC.docx"参照
 *
 * 別紙"機能仕様書_多目的俯瞰画像合成マネージャRTC.docx"参照
 *
 * 別紙"機能仕様書_多目的俯瞰画像合成マネージャRTC.docx"参照
 *
 */
class VersatileOverheadManager
  : public RTC::DataFlowComponentBase
{
 public:
  /*!
   * @brief constructor
   * @param manager Maneger Object
   */
  VersatileOverheadManager(RTC::Manager* manager);

  /*!
   * @brief destructor
   */
  ~VersatileOverheadManager();

  // <rtc-template block="public_attribute">
  
  // </rtc-template>

  // <rtc-template block="public_operation">
  
  // </rtc-template>

  /***
   * 多目的俯瞰画像合成マネージャRTCの初期化処理
   *
   * The initialize action (on CREATED->ALIVE transition)
   * formaer rtc_init_entry() 
   *
   * @return RTC::ReturnCode_t
   * 
   * @pre -
   * @post -
   * 
   */
   virtual RTC::ReturnCode_t onInitialize();

  /***
   * 多目的俯瞰画像合成マネージャRTCの終了処理
   *
   * The finalize action (on ALIVE->END transition)
   * formaer rtc_exiting_entry()
   *
   * @return RTC::ReturnCode_t
   * 
   * @pre -
   * @post -
   * 
   */
   virtual RTC::ReturnCode_t onFinalize();

  /***
   *
   * The startup action when ExecutionContext startup
   * former rtc_starting_entry()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
  // virtual RTC::ReturnCode_t onStartup(RTC::UniqueId ec_id);

  /***
   *
   * The shutdown action when ExecutionContext stop
   * former rtc_stopping_entry()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
  // virtual RTC::ReturnCode_t onShutdown(RTC::UniqueId ec_id);

  /***
   * 多目的俯瞰画像合成マネージャRTCの開始処理
   *
   * The activated action (Active state entry action)
   * former rtc_active_entry()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * @pre -
   * @post -
   * 
   */
   virtual RTC::ReturnCode_t onActivated(RTC::UniqueId ec_id);

  /***
   * 多目的俯瞰画像合成マネージャRTCの停止処理
   *
   * The deactivated action (Active state exit action)
   * former rtc_active_exit()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * @pre -
   * @post -
   * 
   */
   virtual RTC::ReturnCode_t onDeactivated(RTC::UniqueId ec_id);

  /***
   * 多目的俯瞰画像合成マネージャRTCの周期処理
   *
   * The execution action that is invoked periodically
   * former rtc_active_do()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * @pre -
   * @post -
   * 
   */
   virtual RTC::ReturnCode_t onExecute(RTC::UniqueId ec_id);

  /***
   * 多目的俯瞰画像合成マネージャRTCのエラー遷移処理
   *
   * The aborting action when main logic error occurred.
   * former rtc_aborting_entry()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * @pre -
   * @post -
   * 
   */
   virtual RTC::ReturnCode_t onAborting(RTC::UniqueId ec_id);

  /***
   *
   * The error action in ERROR state
   * former rtc_error_do()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
  // virtual RTC::ReturnCode_t onError(RTC::UniqueId ec_id);

  /***
   *
   * The reset action that is invoked resetting
   * This is same but different the former rtc_init_entry()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
  // virtual RTC::ReturnCode_t onReset(RTC::UniqueId ec_id);
  
  /***
   *
   * The state update action that is invoked after onExecute() action
   * no corresponding operation exists in OpenRTm-aist-0.2.0
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
  // virtual RTC::ReturnCode_t onStateUpdate(RTC::UniqueId ec_id);

  /***
   *
   * The action that is invoked when execution context's rate is changed
   * no corresponding operation exists in OpenRTm-aist-0.2.0
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
  // virtual RTC::ReturnCode_t onRateChanged(RTC::UniqueId ec_id);


 protected:
  // <rtc-template block="protected_attribute">
  
  // </rtc-template>

  // <rtc-template block="protected_operation">
  
  // </rtc-template>

  // Configuration variable declaration
  // <rtc-template block="config_declare">

  // </rtc-template>

  // DataInPort declaration
  // <rtc-template block="inport_declare">
  
  // </rtc-template>


  // DataOutPort declaration
  // <rtc-template block="outport_declare">
  
  // </rtc-template>

  // CORBA Port declaration
  // <rtc-template block="corbaport_declare">
  /*!
   * システム状態管理関連のインターフェース
   * Interface: システム状態や動作完了通知を提供する
   */
  RTC::CorbaPort m_VersatileMgrStsServPort;
  /*!
   * 多目的俯瞰画像合成GUI
   * RTCが管理するキー操作要求関連のインターフェース
   * Interface: キーが押下されたことを通知する
   */
  RTC::CorbaPort m_VersatileGuiDBReqServPort;
  /*!
   * 画像付加データDB RTCへのリクエスト関連のインターフェース
   * Interface: 画像付加データDBのデータ登録や、撮影計画リストの作
   *            成及び、取得などの要求を行う
   */
  RTC::CorbaPort m_AdditionalDBReqServPort;
  /*!
   * 画像付加データDB RTCのステータスを提供するインターフェース
   * Interface: 画像付加データDB RTCのステータスを提供する
   */
  RTC::CorbaPort m_AdditionalDBStsServPort;
  /*!
   * タイル生成RTCへのリクエスト関連のインターフェース
   * Interface: タイル生成要求を行う
   */
  RTC::CorbaPort m_TileGenerateReqServPort;
  /*!
   * タイル生成RTCのステータスを提供するインターフェース
   * Interface: タイル生成RTCのステータスを提供する
   */
  RTC::CorbaPort m_TileGenerateStsServPort;
  /*!
   * MapデータDB RTCへのリクエスト関連のインターフェース
   * Interface: MapデータDBのデータ登録や、合成計画リストの作成及び
   *            取得などの要求を行う
   */
  RTC::CorbaPort m_MapDataDBReqServPort;
  /*!
   * 地図データDB RTCのステータスを提供するインターフェース
   * Interface: 地図データDB RTCのステータスを提供する
   */
  RTC::CorbaPort m_MapDataDBStsServPort;
  /*!
   * 地図画像セレクトRTCへのリクエスト関連のインターフェース
   * Interface: 地図画像の取得やスクロールなどの操作要求を行う
   */
  RTC::CorbaPort m_MapImageSelectReqServPort;
  /*!
   * 地図画像セレクタRTCのステータスを提供するインターフェース
   * Interface: 地図画像セレクタRTCのステータスを提供する
   */
  RTC::CorbaPort m_MapImageStsServPort;
  /*!
   * Crawler View画像合成RTCへのリクエスト関連のインターフェース
   * Interface: 画像合成や、データ取得などの要求を行う
   */
  RTC::CorbaPort m_CrawlerViewReqServPort;
  /*!
   * View画像合成RTCのステータスを提供するインターフェース
   * Interface: Crawler View画像合成RTCのステータスを提供する
   */
  RTC::CorbaPort m_CrawlerViewStsServPort;
  
  // </rtc-template>

  // Service declaration
  // <rtc-template block="service_declare">
  /*!
   * システムの現在の状態を提供する
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  VersatileMgrStsSVC_impl m_VersatileMgrStsProv;
  /*!
   * システムの動作完了通知を提供する
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  VersatileMgrCompNoticeSVC_impl m_VersatileMgrCompNoticeProv;
  
  // </rtc-template>

  // Consumer declaration
  // <rtc-template block="consumer_declare">
  /*!
   * GUIのDB登録キーが押下されたことを通知する
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<VersatileGuiDBReqServ::GuiReqDBRegistKey> m_GuiReqDBRegistKeyCons;
  /*!
   * GUIの合成計画リスト削除キーが押下されたことを通知する
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<VersatileGuiDBReqServ::GuiReqSynthesisPlanListDelKey> m_GuiReqSynthesisPlanListDelKeyCons;
  /*!
   * GUIのタイル生成キーが押下されたことを通知する
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<VersatileGuiDBReqServ::GuiReqTileGenerationKey> m_GuiReqTileGenerationKeyCons;
  /*!
   * GUIの表示更新キーが押下されたことを通知する
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<VersatileGuiDBReqServ::GuiReqDisplayUpdateKey> m_GuiReqDisplayUpdateKeyCons;
  /*!
   * GUIの十字キーが押下されたことを通知する
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<VersatileGuiDBReqServ::GuiReqArrowKey> m_GuiReqArrowKeyCons;
  /*!
   * GUIのZoom調整キーが押下されたことを通知する
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<VersatileGuiDBReqServ::GuiReqZoomKey> m_GuiReqZoomKeyCons;
  /*!
   * GUIの地図切り替えキーが押下されたことを通知する
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<VersatileGuiDBReqServ::GuiReqMapChangeKey> m_GuiReqMapChangeKeyCons;
  /*!
   * 画像付加データDBへデータ登録要求を行う
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<AdditionalDBReqServ::AddDBReqRegistAddData> m_AddDBReqRegistAddDataCons;
  /*!
   * 撮影計画リスト作成要求を行う
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<AdditionalDBReqServ::AddDBReqMakeShootingPlanList> m_AddDBReqMakeShootingPlanListCons;
  /*!
   * 撮影計画リストの取得要求を行う
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<AdditionalDBReqServ::AddDBReqGetShootingPlanList> m_AddDBReqGetShootingPlanListCons;
  /*!
   * 画像付加データDB制御RTCの動作完了通知を行う
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<AdditionalDBStsServ::AddDBNotice> m_AddDBNoticeCons;
  /*!
   * タイル生成要求を行う
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<TileGenerateReqServ::TileGenerateReqMakeTile> m_TileGenerateReqMakeTileCons;
  /*!
   * タイル生成RTCの動作完了通知を行う
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<TileGenerateStsServ::TileGenerateNotice> m_TileGenerateNoticeCons;
  /*!
   * 地図データDBへデータ登録要求を行う
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<MapDataDBReqServ::MapDBReqRegistAddData> m_MapDBReqRegistAddDataCons;
  /*!
   * 合成計画リスト作成要求を行う
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<MapDataDBReqServ::MapDBReqMakeSynthesisPlanList> m_MapDBReqMakeSynthesisPlanListCons;
  /*!
   * 合成計画リストの取得要求を行う
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<MapDataDBReqServ::MapDBReqGetSynthesisPlanList> m_MapDBReqGetSynthesisPlanListCons;
  /*!
   * 合成計画リストの削除要求を行う
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<MapDataDBReqServ::MapDBReqDelSynthesisPlanList> m_MapDBReqDelSynthesisPlanListCons;
  /*!
   * 地図データDB制御RTCの動作完了通知を行う
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<MapDataDBStsServ::MapDataDBNotice> m_MapDataDBNoticeCons;
  /*!
   * 地図画像データDBから画像を検索する要求を行う
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<MapImageSelectReqServ::MapImageReqSelectImage> m_MapImageReqSelectImageCons;
  /*!
   * 地図のスクロール要求を行う
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<MapImageSelectReqServ::MapImageReqScroll> m_MapImageReqScrollCons;
  /*!
   * 地図のズームレベル調整要求を行う
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<MapImageSelectReqServ::MapImageReqAdjZoom> m_MapImageReqAdjZoomCons;
  /*!
   * 地図切り替え要求を行う
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<MapImageSelectReqServ::MapImageReqAdjMapChange> m_MapImageReqAdjMapChangeCons;
  /*!
   * 地図画像セレクトRTCの動作完了通知を行う
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<MapImageStsServ::MapImageNotice> m_MapImageNoticeCons;
  /*!
   * 画像合成要求を行う
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<CrawlerViewReqServ::CrawlerViewReqSynthesis> m_CrawlerViewReqSynthesisCons;
  /*!
   * スライド切り替え要求を行う
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<CrawlerViewReqServ::CrawlerViewReqSlide> m_CrawlerViewReqSlideCons;
  /*!
   * Crawler View画像合成RTCの動作完了通知を行う
   * - Argument:      別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Return Value:  別紙"機能仕様書_多目的俯瞰画像合成マネージャ
   *                  RTC.docx"参照
   * - Exception:     なし
   * - PreCondition:  -
   * - PostCondition: -
   */
  RTC::CorbaConsumer<CrawlerViewStsServ::CrawlerViewNotice> m_CrawlerViewNoticeCons;
  
  // </rtc-template>

 private:
  // <rtc-template block="private_attribute">
  
  // </rtc-template>

  // <rtc-template block="private_operation">
  
  // </rtc-template>
  //Add

  void VersatileMgrInit(void);
  bool_type		blVersatileMgrMatrixTrgSet(void);
  uhword_type	uhwVersatileMgrMatrixCheck(void);
  uhword_type	uhwProcExe(void);

  bool_type		blAddDBNoticeCheck(uhword_type &);
  bool_type		blTileGenerateNoticeCheck(uhword_type &);
  bool_type		blMapDataDBNoticeCheck(uhword_type &);
  bool_type		blMapImageSelectNoticeCheck(uhword_type &);
  bool_type		blCrawlerViewNoticeCheck(uhword_type &);
  bool_type		blVersatileGuiTriggerSet(uhword_type &);

  bool_type		blGuiReqDBRegistKeyCheck(uhword_type &);
  bool_type		blGuiReqTileGenerateKeyCheck(uhword_type &);
  bool_type		blGuiReqDispUpDateKeyCheck(uhword_type &);
  bool_type		blGuiReqSyntheListDelKeyCheck(uhword_type &);
  bool_type		blGuiReqArrowKeyCheck(uhword_type &);
  bool_type		blGuiReqZoomKeyCheck(uhword_type &);
  bool_type		blGuiReqMapChangeKeyCheck(uhword_type &);

  uhword_type	uhwProcReqDroneShootListRead(void);
  uhword_type	uhwProcReqCrawlerShootListRead(void);
  uhword_type	uhwProcReqSyntheListRead(void);
  uhword_type	uhwProcNoticeAllListReadEnd(void);
  uhword_type	uhwProcReqDBRegist(void);
  uhword_type	uhwProcNoticeDBRegistEnd(void);
  uhword_type	uhwProcReqTileGenerate(void);
  uhword_type	uhwProcNoticeTileGenerateEnd(void);
  uhword_type	uhwProcReqDispUpdate(void);
  uhword_type	uhwProcNoticeDispUpdateEnd(void);
  uhword_type	uhwProcNoticeImageOperationEnd(void);
  uhword_type	uhwProcReqSyntheListDel(void);
  uhword_type	uhwProcNoticeSyntheListDelEnd(void);
  uhword_type	uhwProcReqArrow(void);
  uhword_type	uhwProcReqZoom(void);
  uhword_type	uhwProcReqMapChange(void);
  uhword_type	uhwProcInitWarningMessage(void);
  uhword_type	uhwProcRunWarningMessage(void);
  uhword_type	uhwProcErrorMessage(void);
  
  //サービスポート接続確認
  bool_type		blGuiReqDBRegistKeyConChk(void);
  bool_type		blGuiReqSynthListDelKeyConChk(void);
  bool_type		blGuiReqTileGeneKeyConChk(void);
  bool_type		blGuiReqDispUpdateKeyConChk(void);
  bool_type		blGuiReqArrowKeyConChk(void);
  bool_type		blGuiReqZoomKeyConChk(void);
  bool_type		blGuiReqMapChangeKeyConChk(void);
  bool_type		blAddDBReqRegistAddDataConChk(void);
  bool_type		blAddDBReqMakeShootListConChk(void);
  bool_type		blAddDBReqGetShootListConChk(void);
  bool_type		blAddDBNoticeConChk(void);
  bool_type		blTileGeneReqMakeTileConChk(void);
  bool_type		blTileGeneNoticeConChk(void);
  bool_type		blMapDBReqRegistAddDataConChk(void);
  bool_type		blMapDBReqMakeSynthListConChk(void);
  bool_type		blMapDBReqGetSynthListConChk(void);
  bool_type		blMapDBReqDelSynthListConChk(void);
  bool_type		blMapDataDBNoticeConChk(void);
  bool_type		blMapImageReqSelImgConChk(void);
  bool_type		blMapImageReqScrollConChk(void);
  bool_type		blMapImageReqAdjZoomConChk(void);
  bool_type		blMapImageReqAdjMapChgConChk(void);
  bool_type		blMapImageNoticeConChk(void);
  bool_type		blCrawlerViewReqSynthConChk(void);
  bool_type		blCrawlerViewReqSlideConChk(void);
  bool_type		blCrawlerViewNoticeConChk(void);

  void	VersatileMgrModeSet(uhword_type);
  void	VersatileMgrNoticeSet(uword_type, uword_type);

  
  //完了通知バックアップ用
  uword_type	m_uwAddDBNotice;					//画像付加データDBコンポーネント用完了通知バックアップ
  uword_type	m_uwTileGenerateNotice;				//タイル生成コンポーネント用完了通知バックアップ
  uword_type	m_uwTileGenerateParam;				//タイル生成コンポーネント用完了通知パラメータバックアップ
  uword_type	m_uwMapDBNotice;					//地図DB完了コンポーネント用完了通知バックアップ
  uword_type	m_uwMapDBParam;						//地図DB完了コンポーネント用完了通知パラメータバックアップ
  uword_type	m_uwMapImageSelNotice;				//地図画像セレクトコンポーネント用完了通知バックアップ
  uword_type	m_uwCrawlerViewNotice;				//Crawler Viewコンポーネント用完了通知バックアップ
  uword_type	m_uwVersatileGuiNotice;				//GUIコンポーネント用完了通知バックアップ


  //キー要求パラメータバックアップ用
  char_type		m_cDBRegistParam[(ROBOT_BASE_PATH_LENGTH + CSV_FOLDER_PATH_LENGTH + 1)];	//DB登録フォルダパス
  TileGenerateKeyParam_st	m_stTileGenerateKeyParam;	//タイル生成パラメータ
  DispUpDate_st	m_stDispUpDateKeyParam;				//表示更新パラメータ
  uword_type	m_uwSyntheListDelParam;				//合成計画リスト削除グループID
  uword_type	m_uwOpeScreen;						//操作画面選択
  uword_type	m_uwArrowParam;						//十字キー押下方向
  uword_type	m_uwZoomParam;						//ズームレベル
  uword_type	m_uwMapChgParam;					//地図の種類

  //マトリクス制御で使用
  uhword_type m_uhwInternalTrg;						//内部トリガ
  uhword_type m_uhwInternalMode;					//内部モード
  uhword_type m_uhwAct;								//アクション

  //画面更新で使用
  uhword_type m_uhwImageDispReqKind;				//画面更新要求の種別
  uhword_type m_uhwMainDispUpDateSts;				//メイン画面更新状態
  uhword_type m_uhwSubDispUpDateSts;				//サブ画面更新状態
  uword_type m_uwSubViewSelect;						//現在のサブ画面のView選択
};


extern "C"
{
  DLL_EXPORT void VersatileOverheadManagerInit(RTC::Manager* manager);
};

#endif // VERSATILEOVERHEADMANAGER_H
