// -*- C++ -*-
/*!
 * @file  VersatileOverheadManager.cpp
 * @brief State management
 * @date $Date$
 *
 * @author 株式会社 東日本計算センター
 *
 * New BSD
 *
 * $Id$
 */

#include "VersatileOverheadManager.h"

// Module specification
// <rtc-template block="module_spec">
static const char* versatileoverheadmanager_spec[] =
  {
    "implementation_id", "VersatileOverheadManager",
    "type_name",         "VersatileOverheadManager",
    "description",       "State management",
    "version",           "1.0.0",
    "vendor",            "EAC",
    "category",          "manager",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "1",
    "language",          "C++",
    "lang_type",         "compile",
    ""
  };
// </rtc-template>

/*!
 * @brief constructor
 * @param manager Maneger Object
 */
VersatileOverheadManager::VersatileOverheadManager(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_VersatileMgrStsServPort("VersatileMgrStsServ"),
    m_VersatileGuiDBReqServPort("VersatileGuiDBReqServ"),
    m_AdditionalDBReqServPort("AdditionalDBReqServ"),
    m_AdditionalDBStsServPort("AdditionalDBStsServ"),
    m_TileGenerateReqServPort("TileGenerateReqServ"),
    m_TileGenerateStsServPort("TileGenerateStsServ"),
    m_MapDataDBReqServPort("MapDataDBReqServ"),
    m_MapDataDBStsServPort("MapDataDBStsServ"),
    m_MapImageSelectReqServPort("MapImageSelectReqServ"),
    m_MapImageStsServPort("MapImageStsServ"),
    m_CrawlerViewReqServPort("CrawlerViewReqServ"),
    m_CrawlerViewStsServPort("CrawlerViewStsServ")

    // </rtc-template>
{
}

/*!
 * @brief destructor
 */
VersatileOverheadManager::~VersatileOverheadManager()
{
}


/*!
 * 多目的俯瞰画像合成マネージャRTCの初期化処理
 */
RTC::ReturnCode_t VersatileOverheadManager::onInitialize()
{
#ifdef _DEBUG
	std::cout << "[debug]VersatileOverheadManager::onInitialize" << std::endl;
#endif

  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  
  // Set OutPort buffer
  
  // Set service provider to Ports
  m_VersatileMgrStsServPort.registerProvider("VersatileMgrSts", "VersatileMgrStsServ::VersatileMgrSts", m_VersatileMgrStsProv);
  m_VersatileMgrStsServPort.registerProvider("VersatileMgrCompNotice", "VersatileMgrStsServ::VersatileMgrCompNotice", m_VersatileMgrCompNoticeProv);
  
  // Set service consumers to Ports
  m_VersatileGuiDBReqServPort.registerConsumer("GuiReqDBRegistKey", "VersatileGuiDBReqServ::GuiReqDBRegistKey", m_GuiReqDBRegistKeyCons);
  m_VersatileGuiDBReqServPort.registerConsumer("GuiReqSynthesisPlanListDelKey", "VersatileGuiDBReqServ::GuiReqSynthesisPlanListDelKey", m_GuiReqSynthesisPlanListDelKeyCons);
  m_VersatileGuiDBReqServPort.registerConsumer("GuiReqTileGenerationKey", "VersatileGuiDBReqServ::GuiReqTileGenerationKey", m_GuiReqTileGenerationKeyCons);
  m_VersatileGuiDBReqServPort.registerConsumer("GuiReqDisplayUpdateKey", "VersatileGuiDBReqServ::GuiReqDisplayUpdateKey", m_GuiReqDisplayUpdateKeyCons);
  m_VersatileGuiDBReqServPort.registerConsumer("GuiReqArrowKey", "VersatileGuiDBReqServ::GuiReqArrowKey", m_GuiReqArrowKeyCons);
  m_VersatileGuiDBReqServPort.registerConsumer("GuiReqZoomKey", "VersatileGuiDBReqServ::GuiReqZoomKey", m_GuiReqZoomKeyCons);
  m_VersatileGuiDBReqServPort.registerConsumer("GuiReqMapChangeKey", "VersatileGuiDBReqServ::GuiReqMapChangeKey", m_GuiReqMapChangeKeyCons);
  m_AdditionalDBReqServPort.registerConsumer("AddDBReqRegistAddData", "AdditionalDBReqServ::AddDBReqRegistAddData", m_AddDBReqRegistAddDataCons);
  m_AdditionalDBReqServPort.registerConsumer("AddDBReqMakeShootingPlanList", "AdditionalDBReqServ::AddDBReqMakeShootingPlanList", m_AddDBReqMakeShootingPlanListCons);
  m_AdditionalDBReqServPort.registerConsumer("AddDBReqGetShootingPlanList", "AdditionalDBReqServ::AddDBReqGetShootingPlanList", m_AddDBReqGetShootingPlanListCons);
  m_AdditionalDBStsServPort.registerConsumer("AddDBNotice", "AdditionalDBStsServ::AddDBNotice", m_AddDBNoticeCons);
  m_TileGenerateReqServPort.registerConsumer("TileGenerateReqMakeTile", "TileGenerateReqServ::TileGenerateReqMakeTile", m_TileGenerateReqMakeTileCons);
  m_TileGenerateStsServPort.registerConsumer("TileGenerateNotice", "TileGenerateStsServ::TileGenerateNotice", m_TileGenerateNoticeCons);
  m_MapDataDBReqServPort.registerConsumer("MapDBReqRegistAddData", "MapDataDBReqServ::MapDBReqRegistAddData", m_MapDBReqRegistAddDataCons);
  m_MapDataDBReqServPort.registerConsumer("MapDBReqMakeSynthesisPlanList", "MapDataDBReqServ::MapDBReqMakeSynthesisPlanList", m_MapDBReqMakeSynthesisPlanListCons);
  m_MapDataDBReqServPort.registerConsumer("MapDBReqGetSynthesisPlanList", "MapDataDBReqServ::MapDBReqGetSynthesisPlanList", m_MapDBReqGetSynthesisPlanListCons);
  m_MapDataDBReqServPort.registerConsumer("MapDBReqDelSynthesisPlanList", "MapDataDBReqServ::MapDBReqDelSynthesisPlanList", m_MapDBReqDelSynthesisPlanListCons);
  m_MapDataDBStsServPort.registerConsumer("MapDataDBNotice", "MapDataDBStsServ::MapDataDBNotice", m_MapDataDBNoticeCons);
  m_MapImageSelectReqServPort.registerConsumer("MapImageReqSelectImage", "MapImageSelectReqServ::MapImageReqSelectImage", m_MapImageReqSelectImageCons);
  m_MapImageSelectReqServPort.registerConsumer("MapImageReqScroll", "MapImageSelectReqServ::MapImageReqScroll", m_MapImageReqScrollCons);
  m_MapImageSelectReqServPort.registerConsumer("MapImageReqAdjZoom", "MapImageSelectReqServ::MapImageReqAdjZoom", m_MapImageReqAdjZoomCons);
  m_MapImageSelectReqServPort.registerConsumer("MapImageReqAdjMapChange", "MapImageSelectReqServ::MapImageReqAdjMapChange", m_MapImageReqAdjMapChangeCons);
  m_MapImageStsServPort.registerConsumer("MapImageNotice", "MapImageStsServ::MapImageNotice", m_MapImageNoticeCons);
  m_CrawlerViewReqServPort.registerConsumer("CrawlerViewReqSynthesis", "CrawlerViewReqServ::CrawlerViewReqSynthesis", m_CrawlerViewReqSynthesisCons);
  m_CrawlerViewReqServPort.registerConsumer("CrawlerViewReqSlide", "CrawlerViewReqServ::CrawlerViewReqSlide", m_CrawlerViewReqSlideCons);
  m_CrawlerViewStsServPort.registerConsumer("CrawlerViewNotice", "CrawlerViewStsServ::CrawlerViewNotice", m_CrawlerViewNoticeCons);
  
  // Set CORBA Service Ports
  addPort(m_VersatileMgrStsServPort);
  addPort(m_VersatileGuiDBReqServPort);
  addPort(m_AdditionalDBReqServPort);
  addPort(m_AdditionalDBStsServPort);
  addPort(m_TileGenerateReqServPort);
  addPort(m_TileGenerateStsServPort);
  addPort(m_MapDataDBReqServPort);
  addPort(m_MapDataDBStsServPort);
  addPort(m_MapImageSelectReqServPort);
  addPort(m_MapImageStsServPort);
  addPort(m_CrawlerViewReqServPort);
  addPort(m_CrawlerViewStsServPort);
  
  // </rtc-template>

  // <rtc-template block="bind_config">
  // </rtc-template>
  
  //追加メンバー変数の初期化
  VersatileMgrInit();

  return RTC::RTC_OK;
}

/*!
 * 多目的俯瞰画像合成マネージャRTCの終了処理
 */

RTC::ReturnCode_t VersatileOverheadManager::onFinalize()
{
#ifdef _DEBUG
	std::cout << "[debug]VersatileOverheadManager::onFinalize()" << std::endl;
#endif

  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t VersatileOverheadManager::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t VersatileOverheadManager::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*!
 * 多目的俯瞰画像合成マネージャRTCの開始処理
 */

RTC::ReturnCode_t VersatileOverheadManager::onActivated(RTC::UniqueId ec_id)
{
#ifdef _DEBUG
	std::cout << "[debug]VersatileOverheadManager::onActivated()" << std::endl;
#endif
	uhword_type uhwResult = RESULT_ERROR;

	//撮影計画リスト読み込み要求
	VersatileMgrModeSet(MGR_MODE_INIT);
	uhwResult = uhwProcReqDroneShootListRead();
	if(uhwResult == RESULT_ERROR){
		//内部モードをエラー状態にする
		VersatileMgrModeSet(MGR_MODE_ERROR);
	}

  return RTC::RTC_OK;
}

/*!
 * 多目的俯瞰画像合成マネージャRTCの停止処理
 */

RTC::ReturnCode_t VersatileOverheadManager::onDeactivated(RTC::UniqueId ec_id)
{
#ifdef _DEBUG
	std::cout << "[debug]VersatileOverheadManager::onDeactivated()" << std::endl;
#endif

	VersatileMgrInit();
	//次回Activate遷移時に撮影計画、合成計画リスト作成から処理する

  return RTC::RTC_OK;
}

/*!
 * 多目的俯瞰画像合成マネージャRTCの周期処理
 */

RTC::ReturnCode_t VersatileOverheadManager::onExecute(RTC::UniqueId ec_id)
{
	bool_type ret = FALSE;
	uhword_type uhwResult = RESULT_ERROR;

	//トリガチェック
	ret = blVersatileMgrMatrixTrgSet();
	if(ret){
		//マトリクスチェック
		uhwResult = uhwVersatileMgrMatrixCheck();
		if(uhwResult == RESULT_SUCCESS){
			//処理実行
			uhwResult = uhwProcExe();
			if(uhwResult == RESULT_ERROR){
				//内部モードをエラー状態にする
				VersatileMgrModeSet(MGR_MODE_ERROR);
			}
		}
	}

  return RTC::RTC_OK;
}

/*!
 * 多目的俯瞰画像合成マネージャRTCのエラー遷移処理
 */

RTC::ReturnCode_t VersatileOverheadManager::onAborting(RTC::UniqueId ec_id)
{
#ifdef _DEBUG
	std::cout << "[debug]VersatileOverheadManager::onAborting()" << std::endl;
#endif

  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t VersatileOverheadManager::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t VersatileOverheadManager::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t VersatileOverheadManager::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t VersatileOverheadManager::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*******************************************************************************
	サブルーチン
********************************************************************************/

/*=============================================================================
	テーブル定義
==============================================================================*/
//画像付加データDB完了通知⇒トリガ変換テーブル
struct NoticeConv_st AddDBTriggerChgTbl[4] ={
	{ADD_DB_NOTICE_REGIST_SUCCESS,			TRG_DB_REG_SUCCESS				},
	{ADD_DB_NOTICE_REGIST_ERROR,			TRG_DB_REG_ERROR				},
	{ADD_DB_NOTICE_SHOOT_LIST_MAKE_SUCCESS, TRG_SHOOT_LIST_CREATE_SUCCESS	},
	{ADD_DB_NOTICE_SHOOT_LIST_MAKE_ERROR,	TRG_SHOOT_LIST_CREATE_ERROR		},
};

//タイル生成完了通知⇒トリガ変換テーブル
struct NoticeConv_st TileGeneTriggerChgTbl[2] ={
	{TILEGENE_NOTICE_GENERATE_SUCCESS,		TRG_TILE_GENE_SUCCESS			},
	{TILEGENE_NOTICE_GENERATE_ERROR,		TRG_TILE_GENE_ERROR				},
};

//地図データDB完了通知⇒トリガ変換テーブル
struct NoticeConv_st MapDBTriggerChgTbl[4] ={
	{MAPDB_MAKE_LIST_SUCCESS,				TRG_SYNTHE_LIST_CREATE_SUCCESS	},
	{MAPDB_MAKE_LIST_ERROR,					TRG_SYNTHE_LIST_CREATE_ERROR	},
	{MAPDB_DEL_LIST_SUCCESS,				TRG_SYNTHE_LIST_DEL_SUCCESS		},
	{MAPDB_DEL_LIST_ERROR,					TRG_SYNTHE_LIST_DEL_ERROR		},
};

//地図画像セレクト完了通知⇒トリガ変換テーブル
struct NoticeConv_st MapImageSelTriggerChgTbl[8] ={
	{MAPSEL_NOTICE_SELECT_SUCCESS,			TRG_MAP_IMAGE_DISP_SUCCESS		},
	{MAPSEL_NOTICE_SELECT_ERROR,			TRG_MAP_IMAGE_DISP_ERROR		},
	{MAPSEL_NOTICE_SCROLL_SUCCESS,			TRG_MAP_IMAGE_OPE_SUCCESS		},
	{MAPSEL_NOTICE_SCROLL_ERROR,			TRG_MAP_IMAGE_OPE_ERROR			},
	{MAPSEL_NOTICE_ZOOM_SUCCESS,			TRG_MAP_IMAGE_OPE_SUCCESS		},
	{MAPSEL_NOTICE_ZOOM_ERROR,				TRG_MAP_IMAGE_OPE_ERROR			},
	{MAPSEL_NOTICE_MAPCHG_SUCCESS,			TRG_MAP_IMAGE_OPE_SUCCESS		},
	{MAPSEL_NOTICE_MAPCHG_ERROR,			TRG_MAP_IMAGE_OPE_ERROR			},
};

//Crawler View完了通知⇒トリガ変換テーブル
struct NoticeConv_st CrawlerViewTriggerChgTbl[4] ={
	{CRAWLER_VIEW_NOTICE_SYNTH_SUCCESS,		TRG_CRAWLER_VIEW_DISP_SUCCESS	},
	{CRAWLER_VIEW_NOTICE_SYNTH_ERROR,		TRG_CRAWLER_VIEW_DISP_ERROR		},
	{CRAWLER_VIEW_NOTICE_SLIDE_SUCCESS,		TRG_CRAWLER_VIEW_OPE_SUCCESS	},
	{CRAWLER_VIEW_NOTICE_SLIDE_ERROR,		TRG_CRAWLER_VIEW_OPE_ERROR		},
};

//マトリクステーブル
struct MatrixContens{
	uhword_type	uhwAct;			//アクション
	uhword_type	uhwMode;		//モード
};

struct MatrixContens VersatileMgrMatrixTbl[][MGR_MODE_MAX] ={
	//起動処理中												//全リスト読み込み中						//待機中												//DB登録中									//タイル生成中								//表示更新準備中							//合成計画リスト削除中							//システム異常
	{{ ACT_NON,						MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON	},	{ ACT_NON,		MGR_MODE_NON	},},	//起動処理正常終了
	{{ ACT_CRAWLER_SHOOT_LIST_READ,	MGR_MODE_ALL_LIST_READ	},	{ ACT_SYNTHE_LIST_READ,	MGR_MODE_NON	},	{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON	},	{ ACT_NON,		MGR_MODE_NON	},},	//撮影計画読み込み正常終了
	{{ ACT_ALLLIST_READ_END,		MGR_MODE_ERROR			},	{ ACT_ALLLIST_READ_END,	MGR_MODE_ERROR	},	{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON	},	{ ACT_NON,		MGR_MODE_NON	},},	//撮影計画読み込み異常終了
	{{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_ALLLIST_READ_END, MGR_MODE_IDLE	},	{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON	},	{ ACT_NON,		MGR_MODE_NON	},},	//合成計画読み込み正常終了
	{{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_ALLLIST_READ_END, MGR_MODE_ERROR	},	{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON	},	{ ACT_NON,		MGR_MODE_NON	},},	//合成計画読み込み異常終了
	{{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_NON, 				MGR_MODE_NON	},	{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_DB_REGIST_END,	MGR_MODE_IDLE	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON	},	{ ACT_NON,		MGR_MODE_NON	},},	//DB登録正常終了
	{{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_NON, 				MGR_MODE_NON	},	{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_DB_REGIST_END,	MGR_MODE_ERROR	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON	},	{ ACT_NON,		MGR_MODE_NON	},},	//DB登録異常終了
	{{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_NON, 				MGR_MODE_NON	},	{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_TILE_GENERATE_END,MGR_MODE_IDLE	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON	},	{ ACT_NON,		MGR_MODE_NON	},},	//タイル生成正常終了
	{{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_NON, 				MGR_MODE_NON	},	{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_TILE_GENERATE_END,MGR_MODE_IDLE	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON	},	{ ACT_NON,		MGR_MODE_NON	},},	//タイル生成異常終了
	{{ ACT_NON,						MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_DISP_UPDATE_END,	MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON	},	{ ACT_NON,		MGR_MODE_NON	},},	//地図画像表示正常終了
	{{ ACT_NON,						MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_DISP_UPDATE_END,	MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON	},	{ ACT_NON,		MGR_MODE_NON	},},	//地図画像表示異常終了
	{{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_NON, 				MGR_MODE_NON	},	{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_IMAGE_OPE_END,	MGR_MODE_IDLE	},	{ ACT_NON,					MGR_MODE_NON	},	{ ACT_NON,		MGR_MODE_NON	},},	//地図操作正常終了
	{{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_NON, 				MGR_MODE_NON	},	{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_IMAGE_OPE_END,	MGR_MODE_IDLE	},	{ ACT_NON,					MGR_MODE_NON	},	{ ACT_NON,		MGR_MODE_NON	},},	//地図操作異常終了
	{{ ACT_NON,						MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_DISP_UPDATE_END,	MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON	},	{ ACT_NON,		MGR_MODE_NON	},},	//Crawler View画像表示正常終了
	{{ ACT_NON,						MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_DISP_UPDATE_END,	MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON	},	{ ACT_NON,		MGR_MODE_NON	},},	//Crawler View画像表示異常終了
	{{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_NON, 				MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_IMAGE_OPE_END,	MGR_MODE_IDLE	},	{ ACT_NON,					MGR_MODE_NON	},	{ ACT_NON,		MGR_MODE_NON	},},	//Crawler View操作正常終了
	{{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_NON, 				MGR_MODE_NON	},	{ ACT_NON,					MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_IMAGE_OPE_END,	MGR_MODE_IDLE	},	{ ACT_NON,					MGR_MODE_NON	},	{ ACT_NON,		MGR_MODE_NON	},},	//Crawler View操作異常終了
	{{ ACT_NON, 					MGR_MODE_NON			}, 	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	}, 	{ ACT_NON,				MGR_MODE_NON	}, 	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_SYNTHE_LIST_DEL_END,	MGR_MODE_IDLE	},	{ ACT_NON,		MGR_MODE_NON	},},	//合成計画リスト削除正常終了
	{{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_NON, 					MGR_MODE_NON			},	{ ACT_NON,				MGR_MODE_NON	}, 	{ ACT_NON,				MGR_MODE_NON	}, 	{ ACT_NON,				MGR_MODE_NON	},	{ ACT_SYNTHE_LIST_DEL_END,	MGR_MODE_ERROR	},	{ ACT_NON,		MGR_MODE_NON	},},	//合成計画リスト削除異常終了
	{{ ACT_INIT_WARNING_MES,		MGR_MODE_NON			},	{ ACT_INIT_WARNING_MES,	MGR_MODE_NON	},	{ ACT_DB_REGIST_START, 		MGR_MODE_DB_REGISTRATION},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,		MGR_MODE_NON	},	{ ACT_ERROR_MES,MGR_MODE_NON	},},	//DB登録キー押下
	{{ ACT_INIT_WARNING_MES,		MGR_MODE_NON			},	{ ACT_INIT_WARNING_MES,	MGR_MODE_NON	},	{ ACT_TILE_GENERATE_START,	MGR_MODE_TILE_GENERATION},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,		MGR_MODE_NON	},	{ ACT_ERROR_MES,MGR_MODE_NON	},},	//タイル生成キー押下
	{{ ACT_INIT_WARNING_MES,		MGR_MODE_NON			},	{ ACT_INIT_WARNING_MES,	MGR_MODE_NON	},	{ ACT_DISP_UPDATE_START, 	MGR_MODE_DISP_READY		},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,		MGR_MODE_NON	},	{ ACT_ERROR_MES,MGR_MODE_NON	},},	//表示更新キー押下
	{{ ACT_INIT_WARNING_MES,		MGR_MODE_NON			},	{ ACT_INIT_WARNING_MES,	MGR_MODE_NON	},	{ ACT_SYNTHE_LIST_DEL_START,MGR_MODE_SYNTHE_LIST_DEL},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,		MGR_MODE_NON	},	{ ACT_ERROR_MES,MGR_MODE_NON	},},	//合成計画リスト削除キー押下
	{{ ACT_INIT_WARNING_MES,		MGR_MODE_NON			},	{ ACT_INIT_WARNING_MES,	MGR_MODE_NON	},	{ ACT_ARROW_OPE_START,		MGR_MODE_DISP_READY		},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,		MGR_MODE_NON	},	{ ACT_ERROR_MES,MGR_MODE_NON	},},	//十字キー押下
	{{ ACT_INIT_WARNING_MES,		MGR_MODE_NON			},	{ ACT_INIT_WARNING_MES,	MGR_MODE_NON	},	{ ACT_ZOOM_ADJ_START,		MGR_MODE_DISP_READY		},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,		MGR_MODE_NON	},	{ ACT_ERROR_MES,MGR_MODE_NON	},},	//ズームレベル設定キー押下
	{{ ACT_INIT_WARNING_MES,		MGR_MODE_NON			},	{ ACT_INIT_WARNING_MES,	MGR_MODE_NON	},	{ ACT_MAP_CHANGE_START,		MGR_MODE_DISP_READY		},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,	MGR_MODE_NON	},	{ ACT_RUN_WARNING_MES,		MGR_MODE_NON	},	{ ACT_ERROR_MES,MGR_MODE_NON	},},	//地図切り替えキー押下
};

struct CompNoticeTrgCnv{
	uhword_type	uhwTrigger;		//完了通知正常
	uword_type	uwNotice;		//完了通知異常
	uhword_type uhwMode;		//更新モード
};

struct CompNoticeTrgCnv DispUpdateNoticeTbl[4] ={
	{	TRG_MAP_IMAGE_DISP_SUCCESS,		MGR_NOTICE_IMAGE_DISP_SUCCESS,	MGR_MODE_IDLE	},
	{	TRG_MAP_IMAGE_DISP_ERROR,		MGR_NOTICE_IMAGE_DISP_ERROR,	MGR_MODE_ERROR	},
	{	TRG_CRAWLER_VIEW_DISP_SUCCESS,	MGR_NOTICE_IMAGE_DISP_SUCCESS,	MGR_MODE_IDLE	},
	{	TRG_CRAWLER_VIEW_DISP_ERROR,	MGR_NOTICE_IMAGE_DISP_ERROR,	MGR_MODE_ERROR	},
};

struct CompNoticeStsConv{
	uword_type	uwNoticeSuccess;	//完了通知正常
	uword_type	uwNoticeError;		//完了通知異常
};

struct CompNoticeStsConv stMainImageNoticeTbl[][2] ={
	{	MGR_NOTICE_MAIN_SCROLL_SUCCESS,		MGR_NOTICE_MAIN_SCROLL_ERROR	},	//MAINDISP_UPDATE_STS_MAP_SCROLL
	{	MGR_NOTICE_MAIN_ZOOMCHG_SUCCESS,	MGR_NOTICE_MAIN_ZOOMCHG_ERROR	},	//MAINDISP_UPDATE_STS_MAP_ZOOM
	{	MGR_NOTICE_MAIN_MAPCHG_SUCCESS,		MGR_NOTICE_MAIN_MAPCHG_ERROR	},	//MAINDISP_UPDATE_STS_MAP_CHG
};

struct CompNoticeStsConv stSubImageNoticeTbl[][2] ={
	{	MGR_NOTICE_SUB_SLIDE_SUCCESS,		MGR_NOTICE_SUB_SLIDE_ERROR		},	//SUBDISP_UPDATE_STS_SLIDE
};




/******************************************************************************************
*	Function Name		：VersatileMgrInit
*	Description			：使用変数処理処理
*	Argument			：なし
*	Return				：なし
******************************************************************************************/
void VersatileOverheadManager::VersatileMgrInit(void)
{
	char_type cFolderPath[STRING_BUFF_MAX_SIZE] = FOLDER_PATH_INIT;

	//追加メンバー変数の初期化
	m_uwAddDBNotice = NOTICE_INIT;
	m_uwTileGenerateNotice = NOTICE_INIT;
	m_uwTileGenerateParam = NOTICE_PARAM_INIT;
	m_uwMapDBNotice = NOTICE_INIT;
	m_uwMapDBParam = NOTICE_PARAM_INIT;
	m_uwMapImageSelNotice = NOTICE_INIT;
	m_uwCrawlerViewNotice = NOTICE_INIT;
	m_uwVersatileGuiNotice = NOTICE_INIT;

	//キー要求パラメータ初期化
	strcpy(m_cDBRegistParam,cFolderPath);
	memset(&m_stTileGenerateKeyParam, 0, sizeof(m_stTileGenerateKeyParam));
	m_stTileGenerateKeyParam.uwRobotCategory = ROBOT_CATEGORY_INIT;
	memset(&m_stDispUpDateKeyParam, 0, sizeof(m_stDispUpDateKeyParam));
	m_uwSyntheListDelParam = GROUP_ID_NON;
	m_uwOpeScreen = OPE_SCREEN_DEF;
	m_uwArrowParam = ARROW_DEF;
	m_uwZoomParam = ZOOM_ADJ_OFF;
	m_uwMapChgParam = MAP_CHENGE_DEF;

	//マトリクス制御で使用
	m_uhwInternalTrg = TRG_NON;
	m_uhwInternalMode = MGR_MODE_INIT;	//内部モードを初期化中に設定
	m_uhwAct = ACT_NON;

	//画面更新変数の初期化
	m_uhwImageDispReqKind = REQ_DISP_UPDATE_NON;
	m_uhwMainDispUpDateSts = MAINDISP_UPDATE_STS_NON;
	m_uhwSubDispUpDateSts = SUBDISP_UPDATE_STS_NON;
	m_uwSubViewSelect = SUB_SCREEN_OFF;

	//サービスポート初期化
//	m_MgrGetDataRequestProv.InitMgrGetDataRequest();
	m_VersatileMgrStsProv.InitVersatileMgrSts();
	m_VersatileMgrCompNoticeProv.InittVersatileMgrCompNotice();

}


/******************************************************************************************
 *	Function Name		：blVersatileMgrMatrixTrgSet
 *	Description			：各コンポーネント完了通知を参照しトリガ要求に変換し設定する
 *	Argument			：なし
 *	Return				：トリガあり/トリガなし
 ******************************************************************************************/
bool_type VersatileOverheadManager::blVersatileMgrMatrixTrgSet(void)
{
	bool_type ret = FALSE;
	bool_type ret2 = FALSE;
	uhword_type uhwInternalTrg = TRG_NON;

	//画像付加DB制御コンポーネントの完了通知変化チェック
	ret = blAddDBNoticeCheck(uhwInternalTrg);
	if(ret == FALSE){
		//タイル生成コンポーネントの完了通知変化チェック
		ret = blTileGenerateNoticeCheck(uhwInternalTrg);
		if(ret == FALSE){
			//地図データDB制御コンポーネントの完了通知変化チェック
			ret = blMapDataDBNoticeCheck(uhwInternalTrg);
			if(ret == FALSE){
				//地図画像セレクトコンポーネントの完了通知変化チェック
				ret = blMapImageSelectNoticeCheck(uhwInternalTrg);
				if(ret == FALSE){
					//Crawler View画像合成コンポーネントの完了通知変化チェック
					ret = blCrawlerViewNoticeCheck(uhwInternalTrg);
				}
			}
		}
	}

	if(ret == FALSE){
		//GUIからの要求をチェック
		ret2 = blVersatileGuiTriggerSet(uhwInternalTrg);
	}

	if(uhwInternalTrg != TRG_NON){
		m_uhwInternalTrg = uhwInternalTrg;
#ifdef _DEBUG
		std::cout << "[debug]VersatileMgrMatrixTrgSet():InternalTrg = " << m_uhwInternalTrg << std::endl;
#endif
		return TRUE;
	}

	return FALSE;
}

/******************************************************************************************
*	Function Name		：blAddDBNoticeCheck
*	Description			：画像付加DB制御コンポーネント完了通知の変化チェック処理
*	Argument			：なし
*	Return				：変化あり/変化なし
******************************************************************************************/
bool_type VersatileOverheadManager::blAddDBNoticeCheck(uhword_type &uhwInternalTrg)
{
	uword_type uwNotice = NOTICE_INIT;
	uword_type uwParam = NOTICE_PARAM_INIT;
	uword_type uwLoopCnt = 0;
	bool_type ret = FALSE;

	//サービスポート接続確認
	if(blAddDBNoticeConChk()){
		m_AddDBNoticeCons->GetAddDBNotice(uwNotice, uwParam);

		if(uwNotice == NOTICE_INIT){
			//初期値のままの場合変化なしとする
			return FALSE;
		}

		if(uwNotice >= ADD_DB_NOTICE_MAX){
			std::cout << "[error]GetAddDBNotice():input parameter error = " << uwNotice << ", " << uwParam << std::endl;
			return FALSE;
		}

		//完了通知チェック
		for(uwLoopCnt = 0 ; uwLoopCnt < (sizeof(AddDBTriggerChgTbl) / sizeof(AddDBTriggerChgTbl[0])); uwLoopCnt ++){
			if(uwNotice == AddDBTriggerChgTbl[uwLoopCnt].uhwNotice){
				std::cout << "[debug]GetAddDBNotice() = " << uwNotice << ", " << uwParam << std::endl;
				uhwInternalTrg = AddDBTriggerChgTbl[uwLoopCnt].uhwTrigger;
				m_uwAddDBNotice = uwNotice;
				m_AddDBNoticeCons->usSetAddDBNotice(NOTICE_INIT, NOTICE_PARAM_INIT);
				ret = TRUE;
				break;
			}
		}
	}
	return ret;
}

/******************************************************************************************
*	Function Name		：blTileGenerateNoticeCheck
*	Description			：タイル生成コンポーネント完了通知の変化チェック処理
*	Argument			：なし
*	Return				：変化あり/変化なし
******************************************************************************************/
bool_type VersatileOverheadManager::blTileGenerateNoticeCheck(uhword_type &uhwInternalTrg)
{
	uword_type uwNotice = NOTICE_INIT;
	uword_type uwParam = NOTICE_PARAM_INIT;
	uword_type uwLoopCnt = 0;
	bool_type ret = FALSE;

	//サービスポート接続確認
	if(blTileGeneNoticeConChk()){
		m_TileGenerateNoticeCons->GetTileGenerateNotice(uwNotice, uwParam);

		if(uwNotice == NOTICE_INIT){
			//初期値のままの場合変化なしとする
			return FALSE;
		}

		if((uwNotice >= TILEGENE_NOTICE_MAX) || (uwParam <= TILE_MODE_INIT) || (uwParam >= TILE_MODE_MAX)){
			std::cout << "[error]GetTileGenerateNotice():input parameter error = " << uwNotice << ", " << uwParam << std::endl;
			return FALSE;
		}

		//完了通知チェック
		for(uwLoopCnt = 0 ; uwLoopCnt < (sizeof(TileGeneTriggerChgTbl) / sizeof(TileGeneTriggerChgTbl[0])); uwLoopCnt ++){
			if(uwNotice == TileGeneTriggerChgTbl[uwLoopCnt].uhwNotice){
				std::cout << "[debug]GetTileGenerateNotice() = " << uwNotice << ", " << uwParam << std::endl;
				uhwInternalTrg = TileGeneTriggerChgTbl[uwLoopCnt].uhwTrigger;
				m_uwTileGenerateNotice = uwNotice;
				m_uwTileGenerateParam = uwParam;
				m_TileGenerateNoticeCons->usSetTileGenerateNotice(NOTICE_INIT, NOTICE_PARAM_INIT);
				ret = TRUE;
				break;
			}
		}
	}
	return ret;
}

/******************************************************************************************
*	Function Name		：blMapDataDBNoticeCheck
*	Description			：地図データDB制御コンポーネント完了通知の変化チェック処理
*	Argument			：なし
*	Return				：変化あり/変化なし
******************************************************************************************/
bool_type VersatileOverheadManager::blMapDataDBNoticeCheck(uhword_type &uhwInternalTrg)
{
	uword_type uwNotice = NOTICE_INIT;
	uword_type uwParam = NOTICE_PARAM_INIT;
	uword_type uwLoopCnt = 0;
	bool_type ret = FALSE;

	//サービスポート接続確認
	if(blMapDataDBNoticeConChk()){
		m_MapDataDBNoticeCons->GetMapDataDBNotice(uwNotice, uwParam);

		if(uwNotice == NOTICE_INIT){
			//初期値のままの場合変化なしとする
			return FALSE;
		}

		if(uwNotice >= MAPDB_NOTICE_MAX){
			std::cout << "[error]GetMapDataDBNotice():input parameter error = " << uwNotice << ", " << uwParam << std::endl;
			return FALSE;
		}

		//完了通知チェック
		for(uwLoopCnt = 0 ; uwLoopCnt < (sizeof(MapDBTriggerChgTbl) / sizeof(MapDBTriggerChgTbl[0])); uwLoopCnt ++){
			if(uwNotice == MapDBTriggerChgTbl[uwLoopCnt].uhwNotice){
				std::cout << "[debug]GetMapDataDBNotice() = " << uwNotice << ", " << uwParam << std::endl;
				uhwInternalTrg = MapDBTriggerChgTbl[uwLoopCnt].uhwTrigger;
				m_uwMapDBNotice = uwNotice;
				m_uwMapDBParam = uwParam;
				m_MapDataDBNoticeCons->usSetMapDataDBNotice(NOTICE_INIT, NOTICE_PARAM_INIT);
				ret = TRUE;
				break;
			}
		}
	}
	return ret;
}

/******************************************************************************************
*	Function Name		：blMapImageSelectNoticeCheck
*	Description			：地図画像セレクトコンポーネント完了通知の変化チェック処理
*	Argument			：なし
*	Return				：変化あり/変化なし
******************************************************************************************/
bool_type VersatileOverheadManager::blMapImageSelectNoticeCheck(uhword_type &uhwInternalTrg)
{
	uword_type uwNotice = NOTICE_INIT;
	uword_type uwParam = NOTICE_PARAM_INIT;
	uword_type uwLoopCnt = 0;
	bool_type ret = FALSE;

	//サービスポート接続確認
	if(blMapImageNoticeConChk()){
		m_MapImageNoticeCons->GetMapImageNotice(uwNotice, uwParam);

		if(uwNotice == NOTICE_INIT){
			//初期値のままの場合変化なしとする
			return FALSE;
		}

		if(uwNotice >= MAPSEL_NOTICE_MAX){
			std::cout << "[error]GetMapImageNotice():input parameter error = " << uwNotice << ", " << uwParam << std::endl;
			return FALSE;
		}

		//完了通知チェック
		for(uwLoopCnt = 0 ; uwLoopCnt < (sizeof(MapImageSelTriggerChgTbl) / sizeof(MapImageSelTriggerChgTbl[0])); uwLoopCnt ++){
			if(uwNotice == MapImageSelTriggerChgTbl[uwLoopCnt].uhwNotice){
				std::cout << "[debug]GetMapImageNotice() = " << uwNotice << ", " << uwParam << std::endl;
				uhwInternalTrg = MapImageSelTriggerChgTbl[uwLoopCnt].uhwTrigger;
				m_uwMapImageSelNotice = uwNotice;
				m_MapImageNoticeCons->usSetMapImageNotice(NOTICE_INIT, NOTICE_PARAM_INIT);
				ret = TRUE;
				break;
			}
		}
	}
	return ret;
}

/******************************************************************************************
*	Function Name		：blCrawlerViewNoticeCheck
*	Description			：Crawler Viewコンポーネント完了通知の変化チェック処理
*	Argument			：なし
*	Return				：変化あり/変化なし
******************************************************************************************/
bool_type VersatileOverheadManager::blCrawlerViewNoticeCheck(uhword_type &uhwInternalTrg)
{
	uword_type uwNotice = NOTICE_INIT;
	uword_type uwParam = NOTICE_PARAM_INIT;
	uword_type uwLoopCnt = 0;
	bool_type ret = FALSE;

	//サービスポート接続確認
	if(blCrawlerViewNoticeConChk()){
		m_CrawlerViewNoticeCons->GetCrawlerViewNotice(uwNotice, uwParam);

		if(uwNotice == NOTICE_INIT){
			//初期値のままの場合変化なしとする
			return FALSE;
		}

		if(uwNotice >= CRAWLER_VIEW_NOTICE_MAX){
			std::cout << "[error]GetCrawlerViewNotice():input parameter error = " << uwNotice << ", " << uwParam << std::endl;
			return FALSE;
		}

		//完了通知チェック
		for(uwLoopCnt = 0 ; uwLoopCnt < (sizeof(CrawlerViewTriggerChgTbl) / sizeof(CrawlerViewTriggerChgTbl[0])); uwLoopCnt ++){
			if(uwNotice == CrawlerViewTriggerChgTbl[uwLoopCnt].uhwNotice){
				std::cout << "[debug]GetCrawlerViewNotice() = " << uwNotice << ", " << uwParam << std::endl;
				uhwInternalTrg = CrawlerViewTriggerChgTbl[uwLoopCnt].uhwTrigger;
				m_uwCrawlerViewNotice = uwNotice;
				m_CrawlerViewNoticeCons->usSetCrawlerViewNotice(NOTICE_INIT, NOTICE_PARAM_INIT);
				ret = TRUE;
				break;
			}
		}
	}
	return ret;
}

/******************************************************************************************
*	Function Name		：blVersatileGuiTriggerSet
*	Description			：GUIコンポーネント完了通知の変化チェック及び、トリガ変換処理
*	Argument			：Out：トリガ
*	Return				：トリガ要求あり/トリガ要求なし
******************************************************************************************/
bool_type VersatileOverheadManager::blVersatileGuiTriggerSet(uhword_type &uhwInternalTrigger)
{
	uhword_type uhwReq = 0;
	bool_type ret = FALSE;
	uhword_type uhwConvTrg = TRG_NON;

	//DB登録キー押下
	ret = blGuiReqDBRegistKeyCheck(uhwConvTrg);
	if(ret == FALSE){
		//タイル生成キー押下
		ret = blGuiReqTileGenerateKeyCheck(uhwConvTrg);
		if(ret == FALSE){
			//表示更新キー押下
			ret = blGuiReqDispUpDateKeyCheck(uhwConvTrg);
			if(ret == FALSE){
				//合成計画リスト削除キー押下
				ret = blGuiReqSyntheListDelKeyCheck(uhwConvTrg);
				if(ret == FALSE){
					//十字キー押下
					ret = blGuiReqArrowKeyCheck(uhwConvTrg);
					if(ret == FALSE){
						//ズームレベル設定キー押下
						ret = blGuiReqZoomKeyCheck(uhwConvTrg);
						if(ret == FALSE){
							//地図切り替えキー押下
							ret = blGuiReqMapChangeKeyCheck(uhwConvTrg);
						}
					}
				}
			}
		}
	}
	
	if(ret){
		uhwInternalTrigger = uhwConvTrg;
		ret = TRUE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blGuiReqDBRegistKeyCheck
*	Description			：DB登録キー押下要求の変化チェック及び、トリガ変換処理
*	Argument			：Out：トリガ
*	Return				：トリガ要求あり/トリガ要求なし
******************************************************************************************/
bool_type VersatileOverheadManager::blGuiReqDBRegistKeyCheck(uhword_type &uhwConvTrg)
{
	char_type *cFolderPath_p;
	char_type cFolderPath[STRING_BUFF_MAX_SIZE] = FOLDER_PATH_INIT;
	uhword_type uhwLen = 0;
	bool_type ret = FALSE;

	//サービスポート接続確認
	 if(blGuiReqDBRegistKeyConChk()){
		//DB登録フォルダパスの取得
		m_GuiReqDBRegistKeyCons->GetGuiReqDBRegistKey(cFolderPath_p);

		strcpy(cFolderPath, cFolderPath_p);

		//取得フォルダパスの空文字チェック
		uhwLen = strlen(cFolderPath_p);
		if(uhwLen == 0){
			//初期値のままの場合未設定としてあつかう
			return FALSE;
		}else if(uhwLen > (ROBOT_BASE_PATH_LENGTH + CSV_FOLDER_PATH_LENGTH)){
			std::cout << "[error]blGuiReqDBRegistKeyCheck():input string over" << std::endl;
			return FALSE;
		}

		//フォルダパスの変化チェック
		if(strcmp(cFolderPath,m_cDBRegistParam)){
			uhwConvTrg = TRG_DB_REGIST_KEY;
			//フォルダパスバックアップ
			strcpy(m_cDBRegistParam,cFolderPath);
			ret = TRUE;
		}
	}
	 return ret;
}

/******************************************************************************************
*	Function Name		：blGuiReqTileGenerateKeyCheck
*	Description			：タイル生成キー押下要求の変化チェック及び、トリガ変換処理
*	Argument			：Out：トリガ
*	Return				：トリガ要求あり/トリガ要求なし
******************************************************************************************/
bool_type VersatileOverheadManager::blGuiReqTileGenerateKeyCheck(uhword_type &uhwConvTrg)
{
	TileGenerateKeyParam_st stParam;
	bool_type ret = FALSE;

	memset(&stParam, 0, sizeof(stParam));

	//サービスポート接続確認
	if(blGuiReqTileGeneKeyConChk()){
		//タイル生成要求パラメータ取得
		m_GuiReqTileGenerationKeyCons->GetGuiReqTileGenerationKey(
			stParam.ulGenerateMode,
			stParam.uwRobotCategory,
			stParam.uwGroupId,
			stParam.dStartLatitude,
			stParam.dStartLongitude,
			stParam.dEndLatitude,
			stParam.dEndLongitude,
			stParam.uwZoomlevel);

		if((stParam.ulGenerateMode == TILE_MODE_INIT) && 
			(stParam.uwRobotCategory == ROBOT_CATEGORY_INIT) &&
			(stParam.uwGroupId == 0) &&
			(stParam.dStartLatitude == 0) &&
			(stParam.dStartLongitude == 0) &&
			(stParam.dEndLatitude == 0) &&
			(stParam.dEndLongitude == 0) &&
			(stParam.uwZoomlevel == ZOOM_LEVEL_DEF)){
			//初期値のままの場合未設定としてあつかう
			return FALSE;
		}

		if((stParam.ulGenerateMode <= TILE_MODE_INIT) ||
			(stParam.ulGenerateMode >= TILE_MODE_MAX) ||
			(stParam.uwRobotCategory == ROBOT_CATEGORY_INIT) ||
			(stParam.uwRobotCategory >= ROBOT_CATEGORY_MAX) ||
			(stParam.uwGroupId == 0) || 
			(stParam.dStartLatitude == 0) ||
			(stParam.dStartLongitude == 0) ||
			(stParam.dEndLatitude == 0) ||
			(stParam.dEndLongitude == 0) ||
			(stParam.uwZoomlevel > ZOOM_LEVEL_MAX)){
			std::cout << "[error]blGuiReqTileGenerateKeyCheck():input parameter error = " << stParam.ulGenerateMode <<  ", " <<
				stParam.uwRobotCategory << ", " << stParam.uwGroupId <<  ", " << stParam.dStartLatitude <<  ", " << stParam.dStartLongitude <<  ", " <<
				stParam.dEndLatitude <<  ", " << stParam.dEndLongitude <<  ", " << stParam.uwZoomlevel <<  ", " <<
			std::endl;
			return FALSE;
		}

		//タイル生成要求パラメータの変化チェック
		if((stParam.ulGenerateMode != m_stTileGenerateKeyParam.ulGenerateMode) ||
			(stParam.uwRobotCategory != m_stTileGenerateKeyParam.uwRobotCategory) ||
			(stParam.uwGroupId != m_stTileGenerateKeyParam.uwGroupId) ||
			(stParam.dStartLatitude != m_stTileGenerateKeyParam.dStartLatitude) ||
			(stParam.dStartLongitude != m_stTileGenerateKeyParam.dStartLongitude) ||
			(stParam.dEndLatitude != m_stTileGenerateKeyParam.dEndLatitude) ||
			(stParam.dEndLongitude != m_stTileGenerateKeyParam.dEndLongitude) ||
			(stParam.uwZoomlevel != m_stTileGenerateKeyParam.uwZoomlevel)){

			uhwConvTrg = TRG_TILE_GENERATE_KEY;
			m_stTileGenerateKeyParam = stParam;
			ret = TRUE;
		}
	}
	return ret;
}

/******************************************************************************************
*	Function Name		：blGuiReqDispUpDateKeyCheck
*	Description			：表示更新キー押下要求の変化チェック及び、トリガ変換処理
*	Argument			：Out：トリガ
*	Return				：トリガ要求あり/トリガ要求なし
******************************************************************************************/
bool_type VersatileOverheadManager::blGuiReqDispUpDateKeyCheck(uhword_type &uhwConvTrg)
{
	DispUpDate_st stDispUpDateParam;
	bool_type ret = FALSE;
	bool_type req_change = FALSE;

	memset(&stDispUpDateParam, 0, sizeof(stDispUpDateParam));

	//サービスポート接続確認
	if(blGuiReqDispUpdateKeyConChk()){

		m_GuiReqDisplayUpdateKeyCons->GetGuiReqDisplayUpdateKey(
			stDispUpDateParam.uwMainViewGroupId,
			stDispUpDateParam.uwSubViewSelect,
			stDispUpDateParam.uwSubViewGroupId);

		if((stDispUpDateParam.uwMainViewGroupId == GROUP_ID_NON) &&
			(stDispUpDateParam.uwSubViewSelect == SUB_SCREEN_MAX) &&
			(stDispUpDateParam.uwSubViewGroupId == GROUP_ID_NON)){
			return FALSE;
		}

		if((stDispUpDateParam.uwSubViewSelect >= SUB_SCREEN_MAX) ||
			((stDispUpDateParam.uwSubViewSelect == SUB_SCREEN_DB_IMAGE) && (stDispUpDateParam.uwSubViewGroupId <= GROUP_ID_NON)) ||
			((stDispUpDateParam.uwSubViewSelect != SUB_SCREEN_DB_IMAGE) && (stDispUpDateParam.uwSubViewGroupId != GROUP_ID_NON))){

			std::cout << "[error]blGuiReqDispUpDateKeyCheck():input parameter error = " << 
				stDispUpDateParam.uwSubViewSelect << ", " << 
				stDispUpDateParam.uwSubViewGroupId << std::endl;
			return FALSE;
		}

		//メイン画面
		if(stDispUpDateParam.uwMainViewGroupId > GROUP_ID_NON){
			m_uhwImageDispReqKind = (m_uhwImageDispReqKind | REQ_DISP_UPDATE_MAIN);
			m_stDispUpDateKeyParam.uwMainViewGroupId = stDispUpDateParam.uwMainViewGroupId;
			req_change = TRUE;
		}

		//サブ画面
		m_stDispUpDateKeyParam.uwSubViewSelect = stDispUpDateParam.uwSubViewSelect;
		m_stDispUpDateKeyParam.uwSubViewGroupId = stDispUpDateParam.uwSubViewGroupId;

		if(m_stDispUpDateKeyParam.uwSubViewSelect == SUB_SCREEN_OFF){
			//画面OFFはGUIで処理するため状態更新及び完了通知のみ返す
			m_uwSubViewSelect = SUB_SCREEN_OFF;
			//Main画面更新要求がない場合後続の処理を実施しない
			if(req_change == FALSE){
				//VersatileMgrNoticeSet(MGR_NOTICE_SUB_DISP_OFF_SUCCESS, NOTICE_PARAM_INIT);
				m_GuiReqDisplayUpdateKeyCons->usSetGuiReqDisplayUpdateKey(GROUP_ID_NON, SUB_SCREEN_MAX, GROUP_ID_NON);
				return FALSE;
			}
		}
		else{
			//SCREEN_OFF以外は要求ありと判断
			m_uhwImageDispReqKind = (m_uhwImageDispReqKind | REQ_DISP_UPDATE_SUB);
			req_change = TRUE;
		}

		if(req_change){
			uhwConvTrg = TRG_DISP_UPDATE_KEY;
			ret = TRUE;
			m_GuiReqDisplayUpdateKeyCons->usSetGuiReqDisplayUpdateKey(GROUP_ID_NON, SUB_SCREEN_MAX, GROUP_ID_NON);
		}
	}
	return ret;

}

/******************************************************************************************
*	Function Name		：blGuiReqSyntheListDelKeyCheck
*	Description			：合成計画リスト削除キー押下要求の変化チェック及び、トリガ変換処理
*	Argument			：Out：トリガ
*	Return				：トリガ要求あり/トリガ要求なし
******************************************************************************************/
bool_type VersatileOverheadManager::blGuiReqSyntheListDelKeyCheck(uhword_type &uhwConvTrg)
{
	uword_type uwGroupID = GROUP_ID_NON;
	bool_type ret = FALSE;

	//サービスポート接続確認
	if(blGuiReqSynthListDelKeyConChk()){
		m_GuiReqSynthesisPlanListDelKeyCons->GetGuiReqSynthesisPlanListDelKey(uwGroupID);

		if(uwGroupID != GROUP_ID_NON){
			uhwConvTrg = TRG_SYNTHE_LIST_DEL_KEY;
			m_uwSyntheListDelParam = uwGroupID;
			m_GuiReqSynthesisPlanListDelKeyCons->usSetGuiReqSynthesisPlanListDelKey(GROUP_ID_NON);
			ret = TRUE;
		}
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blGuiReqArrowKeyCheck
*	Description			：十字キー押下要求の変化チェック及び、トリガ変換処理
*	Argument			：Out：トリガ
*	Return				：トリガ要求あり/トリガ要求なし
******************************************************************************************/
bool_type VersatileOverheadManager::blGuiReqArrowKeyCheck(uhword_type &uhwConvTrg)
{
	uword_type uwOpeScreen = OPE_SCREEN_DEF;
	uword_type uwArrow = ARROW_DEF;
	bool_type ret = FALSE;

	//サービスポート接続確認
	if(blGuiReqArrowKeyConChk()){
		m_GuiReqArrowKeyCons->GetGuiReqArrowKey(uwOpeScreen, uwArrow);

		if((uwOpeScreen >= OPE_SCREEN_MAX) || (uwArrow >= ARROW_MAX)){
			std::cout << "[error]blGuiReqArrowKeyCheck():input parameter error = " << uwOpeScreen << ", " <<  uwArrow << std::endl;
			return FALSE;
		}

		if(uwArrow != ARROW_OFF){
			uhwConvTrg = TRG_ARROW_KEY;
			m_uwOpeScreen = uwOpeScreen;
			m_uwArrowParam = uwArrow;
			m_GuiReqArrowKeyCons->usSetGuiReqArrowKey(OPE_SCREEN_DEF, ARROW_DEF);
			ret = TRUE;
		}
	}
	return ret;
}

/******************************************************************************************
*	Function Name		：blGuiReqZoomKeyCheck
*	Description			：ズームレベル調整キー押下要求の変化チェック及び、トリガ変換処理
*	Argument			：Out：トリガ
*	Return				：トリガ要求あり/トリガ要求なし
******************************************************************************************/
bool_type VersatileOverheadManager::blGuiReqZoomKeyCheck(uhword_type &uhwConvTrg)
{
	uword_type uwOpeScreen = OPE_SCREEN_DEF;
	uword_type uwZoomAdj = ZOOM_ADJ_OFF;
	bool_type ret = FALSE;

	//サービスポート接続確認
	if(blGuiReqZoomKeyConChk()){
		m_GuiReqZoomKeyCons->GetGuiReqZoomKey(uwOpeScreen, uwZoomAdj);

		if((uwOpeScreen != OPE_SCREEN_MAIN) || (uwZoomAdj >= ZOOM_ADJ_MAX)){
			std::cout << "[error]blGuiReqZoomKeyCheck():input parameter error = " << uwOpeScreen << ", " <<  uwZoomAdj << std::endl;
			return FALSE;
		}

		if(uwZoomAdj != ZOOM_ADJ_OFF){
			uhwConvTrg = TRG_ZOOM_KEY;
			m_uwZoomParam = uwZoomAdj;
			ret = TRUE;
			m_GuiReqZoomKeyCons->usSetGuiReqZoomKey(OPE_SCREEN_DEF, ZOOM_ADJ_OFF);
		}
	}
	return ret;
}

/******************************************************************************************
*	Function Name		：blGuiReqMapChangeKeyCheck
*	Description			：地図切り替えキー押下要求の変化チェック及び、トリガ変換処理
*	Argument			：Out：トリガ
*	Return				：トリガ要求あり/トリガ要求なし
******************************************************************************************/
bool_type VersatileOverheadManager::blGuiReqMapChangeKeyCheck(uhword_type &uhwConvTrg)
{
	uword_type uwOpeScreen = OPE_SCREEN_DEF;
	uword_type uwMapKind = MAP_CHENGE_DEF;
	bool_type ret = FALSE;

	//サービスポート接続確認
	if(blGuiReqMapChangeKeyConChk()){
		m_GuiReqMapChangeKeyCons->GetGuiReqMapChangeKey(uwOpeScreen,uwMapKind);

		if((uwOpeScreen != OPE_SCREEN_MAIN) || (uwMapKind >= MAP_KIND_MAX)){
			std::cout << "[error]blGuiReqMapChangeKeyCheck():input parameter error = " << uwOpeScreen << ", " <<  uwMapKind << std::endl;
			return FALSE;
		}

		if(uwMapKind != m_uwMapChgParam){
			uhwConvTrg = TRG_MAP_CHANGE;
			m_uwMapChgParam = uwMapKind;
			ret = TRUE;
		}
	}
	return ret;
}

/*******************************************************************************
 *	Function Name		：uhwVersatileMgrMatrixCheck
 *	Description			：マトリクスチェック処理
 *	Argument			：なし
 *	Return				：正常終了/異常終了
 *******************************************************************************/
uhword_type VersatileOverheadManager::uhwVersatileMgrMatrixCheck(void)
{
	uhword_type uhwMode = MGR_MODE_NON;

	if((m_uhwInternalTrg >= TRG_MAX) || (m_uhwInternalMode >= MGR_MODE_MAX)){
		return RESULT_ERROR;
	}

	m_uhwAct = VersatileMgrMatrixTbl[m_uhwInternalTrg][m_uhwInternalMode].uhwAct;
	uhwMode = VersatileMgrMatrixTbl[m_uhwInternalTrg][m_uhwInternalMode].uhwMode;

	//内部モードを更新
	if(uhwMode != MGR_MODE_NON){
		if(m_uhwInternalMode != uhwMode){
			VersatileMgrModeSet(uhwMode);
		}
	}

	return RESULT_SUCCESS;
}

/*******************************************************************************
*	Function Name		：uhwProcExe
*	Description			：プロセス実行処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcExe(void)
{
	uhword_type uhwRet = RESULT_ERROR;

	//実行処理テーブル
	uhword_type(VersatileOverheadManager::*RunProcTable1[])(void) ={
		&VersatileOverheadManager::uhwProcReqDroneShootListRead,		//ACT_DRONE_SHOOT_LIST_READ
		&VersatileOverheadManager::uhwProcReqCrawlerShootListRead,		//ACT_CRAWLER_SHOOT_LIST_READ
		&VersatileOverheadManager::uhwProcReqSyntheListRead,			//ACT_SYNTHE_LIST_READ
		&VersatileOverheadManager::uhwProcNoticeAllListReadEnd,			//ACT_ALLLIST_READ_END
		&VersatileOverheadManager::uhwProcReqDBRegist,					//ACT_DB_REGIST_START
		&VersatileOverheadManager::uhwProcNoticeDBRegistEnd,			//ACT_DB_REGIST_END
		&VersatileOverheadManager::uhwProcReqTileGenerate,				//ACT_TILE_GENERATE_START
		&VersatileOverheadManager::uhwProcNoticeTileGenerateEnd,		//ACT_TILE_GENERATE_END
		&VersatileOverheadManager::uhwProcReqDispUpdate,				//ACT_DISP_UPDATE_START
		&VersatileOverheadManager::uhwProcNoticeDispUpdateEnd,			//ACT_DISP_UPDATE_END
		&VersatileOverheadManager::uhwProcNoticeImageOperationEnd,		//ACT_IMAGE_OPE_END
		&VersatileOverheadManager::uhwProcReqSyntheListDel,				//ACT_SYNTHE_LIST_DEL_START
		&VersatileOverheadManager::uhwProcNoticeSyntheListDelEnd,		//ACT_SYNTHE_LIST_DEL_END
		&VersatileOverheadManager::uhwProcReqArrow,						//ACT_ARROW_OPE_START
		&VersatileOverheadManager::uhwProcReqZoom,						//ACT_ZOOM_ADJ_START
		&VersatileOverheadManager::uhwProcReqMapChange,					//ACT_MAP_CHANGE_START
		&VersatileOverheadManager::uhwProcInitWarningMessage,			//ACT_INIT_WARNING_MES
		&VersatileOverheadManager::uhwProcRunWarningMessage,			//ACT_RUN_WARNING_MES
		&VersatileOverheadManager::uhwProcErrorMessage,					//ACT_ERROR_MES
	};

	//処理実行
	if((m_uhwAct != ACT_NON) && (m_uhwAct < ACT_MAX)){
		uhwRet = (this->*RunProcTable1[m_uhwAct])();
#ifdef _DEBUG
		std::cout << "[debug]uhwProcExe():procid = " << m_uhwAct <<",Result = " << uhwRet << std::endl;
#endif
	}

	return uhwRet;
}

/*******************************************************************************
*	Function Name		：uhwProcReqShootListRead
*	Description			：撮影計画リスト作成要求処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcReqDroneShootListRead(void)
{
	uhword_type uhwRet = RESULT_ERROR;
	uhword_type uhwServRet = RESULT_NACK;

	//サービスポート接続確認
	if(blAddDBReqMakeShootListConChk()){
		//撮影計画リスト作成要求を行う
		uhwServRet = m_AddDBReqMakeShootingPlanListCons->usSetAddDBReqMakeShootingPlanList(ROBOT_CATEGORY_DRONE);
		if(uhwServRet == RESULT_ACK){
			std::cout << "[debug]usSetAddDBReqMakeShootingPlanList = " << uhwServRet << ", Param = " << ROBOT_CATEGORY_DRONE << std::endl;
			uhwRet = RESULT_SUCCESS;
		}else{
			std::cout << "[error]usSetAddDBReqMakeShootingPlanList = " << uhwServRet << ", Param = " << ROBOT_CATEGORY_DRONE << std::endl;
			uhwRet = RESULT_ERROR;
		}
	}
	return uhwRet;
}

/*******************************************************************************
*	Function Name		：uhwProcReqShootListRead
*	Description			：撮影計画リスト作成要求処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcReqCrawlerShootListRead(void)
{
	uhword_type uhwRet = RESULT_ERROR;
	uhword_type uhwServRet = RESULT_NACK;

	//サービスポート接続確認
	if(blAddDBReqMakeShootListConChk()){
		//撮影計画リスト作成要求を行う
		uhwServRet = m_AddDBReqMakeShootingPlanListCons->usSetAddDBReqMakeShootingPlanList(ROBOT_CATEGORY_CRAWLER);
		if(uhwServRet == RESULT_ACK){
			std::cout << "[debug]usSetAddDBReqMakeShootingPlanList = " << uhwServRet << ", Param = " << ROBOT_CATEGORY_CRAWLER << std::endl;
			uhwRet = RESULT_SUCCESS;
		}
		else{
			std::cout << "[error]usSetAddDBReqMakeShootingPlanList = " << uhwServRet << ", Param = " << ROBOT_CATEGORY_CRAWLER << std::endl;
			uhwRet = RESULT_ERROR;
		}
	}
	return uhwRet;
}

/*******************************************************************************
*	Function Name		：uhwProcReqSyntheListRead
*	Description			：合成計画リスト作成要求処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcReqSyntheListRead(void)
{ 
	uhword_type uhwRet = RESULT_ERROR;
	uhword_type uhwServRet = RESULT_NACK;

	//サービスポート接続確認
	if(blMapDBReqMakeSynthListConChk()){
		//撮影計画リスト作成要求を行う
		uhwServRet = m_MapDBReqMakeSynthesisPlanListCons->usSetMapDBReqMakeSynthesisPlanList(SERV_REQ_SET);
		if(uhwServRet == RESULT_ACK){
			std::cout << "[debug]usSetMapDBReqMakeSynthesisPlanList = " << uhwServRet << ", Param = " << SERV_REQ_SET << std::endl;
			uhwRet = RESULT_SUCCESS;
		}else{
			std::cout << "[error]usSetMapDBReqMakeSynthesisPlanList = " << uhwServRet << ", Param = " << SERV_REQ_SET << std::endl;
			uhwRet = RESULT_ERROR;
		}
	}
	return uhwRet;
}

/*******************************************************************************
*	Function Name		：uhwProcNoticeAllListReadEnd
*	Description			：全リストデータ読み込み完了通知処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcNoticeAllListReadEnd(void)
{ 
	uhword_type uhwRet = RESULT_ERROR;
	uhword_type uhwServRet = RESULT_NACK;
	uword_type uwNotice = NOTICE_INIT;
	uword_type uwParam = NOTICE_PARAM_INIT;

	switch(m_uhwInternalTrg){
	case	TRG_SYNTHE_LIST_CREATE_SUCCESS:
		uwNotice = MGR_NOTICE_ALL_LIST_READ_SUCCESS;
		break;
	case	TRG_SHOOT_LIST_CREATE_ERROR:
	case	TRG_SYNTHE_LIST_CREATE_ERROR:
		uwNotice = MGR_NOTICE_ALL_LIST_READ_ERROR;
		break;
	default:
		return RESULT_ERROR;
	}

	//全リスト読み込み完了通知設定
	VersatileMgrNoticeSet(uwNotice, uwParam);

	return RESULT_SUCCESS;
}

/*******************************************************************************
*	Function Name		：uhwProcReqDBRegist
*	Description			：DB登録要求処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcReqDBRegist(void)
{ 
	uhword_type uhwRet = RESULT_ERROR;
	uhword_type uhwServRet = RESULT_NACK;

	//サービスポート接続確認
	if(blAddDBReqRegistAddDataConChk()){
		uhwServRet = m_AddDBReqRegistAddDataCons->usSetAddDBReqRegistAddData(m_cDBRegistParam);
		if(uhwServRet == RESULT_ACK){
			std::cout << "[debug]usSetAddDBReqRegistAddData = " << uhwServRet << ", Param = " << m_cDBRegistParam << std::endl;
			uhwRet = RESULT_SUCCESS;
		}else{
			std::cout << "[error]usSetAddDBReqRegistAddData = " << uhwServRet << ", Param = " << m_cDBRegistParam << std::endl;
			uhwRet = RESULT_ERROR;
		}
	}
	return uhwRet;
}

/*******************************************************************************
*	Function Name		：uhwProcNoticeDBRegistEnd
*	Description			：DB登録完了通知処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcNoticeDBRegistEnd(void)
{ 
	uhword_type uhwRet = RESULT_ERROR;
	uhword_type uhwServRet = RESULT_NACK;
	uword_type uwNotice = NOTICE_INIT;
	uword_type uwParam = NOTICE_PARAM_INIT;

	switch(m_uhwInternalTrg){
	case	TRG_DB_REG_SUCCESS:
		uwNotice = MGR_NOTICE_DB_REGIST_SUCCESS;
		break;
	case	TRG_DB_REG_ERROR:
		uwNotice = MGR_NOTICE_DB_REGIST_ERROR;
		break;
	default:
		return RESULT_ERROR;
	}

	//DB登録完了通知設定
	VersatileMgrNoticeSet(uwNotice, uwParam);

	return RESULT_SUCCESS;
}

/*******************************************************************************
*	Function Name		：uhwProcReqTileGenerate
*	Description			：タイル生成要求処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcReqTileGenerate(void)
{ 
	uhword_type uhwRet = RESULT_ERROR;
	uhword_type uhwServRet = RESULT_NACK;

	//サービスポート接続確認
	if(blTileGeneReqMakeTileConChk()){
		uhwServRet = m_TileGenerateReqMakeTileCons->usSetTileGenerateReqMakeTile(
			m_stTileGenerateKeyParam.ulGenerateMode,
			m_stTileGenerateKeyParam.uwRobotCategory,
			m_stTileGenerateKeyParam.uwGroupId,
			m_stTileGenerateKeyParam.dStartLatitude,
			m_stTileGenerateKeyParam.dStartLongitude,
			m_stTileGenerateKeyParam.dEndLatitude,
			m_stTileGenerateKeyParam.dEndLongitude,
			m_stTileGenerateKeyParam.uwZoomlevel);

		if(uhwServRet == RESULT_ACK){
			std::cout << "[debug]usSetMapDBReqMakeSynthesisPlanList = " << uhwServRet << ", Param1 = " << m_stTileGenerateKeyParam.ulGenerateMode
				<< ", Param2 = " << m_stTileGenerateKeyParam.uwRobotCategory << ", Param3 = " << m_stTileGenerateKeyParam.uwGroupId
				<< ", Param4 = " << m_stTileGenerateKeyParam.dStartLatitude << ", Param5 = " << m_stTileGenerateKeyParam.dStartLongitude
				<< ", Param6 = " << m_stTileGenerateKeyParam.dEndLatitude << ", Param7 = " << m_stTileGenerateKeyParam.dEndLongitude
				<< ", Param8 = " << m_stTileGenerateKeyParam.uwZoomlevel << std::endl;
			uhwRet = RESULT_SUCCESS;
		}else{
			std::cout << "[error]usSetMapDBReqMakeSynthesisPlanList = " << uhwServRet << ", Param1 = " << m_stTileGenerateKeyParam.ulGenerateMode
				<< ", Param2 = " << m_stTileGenerateKeyParam.uwRobotCategory << ", Param3 = " << m_stTileGenerateKeyParam.uwGroupId
				<< ", Param4 = " << m_stTileGenerateKeyParam.dStartLatitude << ", Param5 = " << m_stTileGenerateKeyParam.dStartLongitude
				<< ", Param6 = " << m_stTileGenerateKeyParam.dEndLatitude << ", Param7 = " << m_stTileGenerateKeyParam.dEndLongitude
				<< ", Param8 = " << m_stTileGenerateKeyParam.uwZoomlevel << std::endl;
			uhwRet = RESULT_ERROR;
		}
	}
	return uhwRet;
}

/*******************************************************************************
*	Function Name		：uhwProcNoticeTileGenerateEnd
*	Description			：タイル生成完了通知処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcNoticeTileGenerateEnd(void)
{ 
	uword_type uwNotice = NOTICE_INIT;
	uword_type uwParam = NOTICE_PARAM_INIT;

	switch(m_uhwInternalTrg){
	case	TRG_TILE_GENE_SUCCESS:
		switch(m_uwTileGenerateParam){
			case TILE_MODE_GENERATE:
				uwNotice = MGR_NOTICE_TILE_GENERATE_SUCCESS;
				break;
			case TILE_MODE_SPLIT_DISP_ON:
				uwNotice = MGR_NOTICE_TILE_SPLIT_DISP_SUCCESS;
				break;
			case TILE_MODE_SPLIT_DISP_OFF:
				uwNotice = MGR_NOTICE_SPLIT_DISP_ERASE_SUCCESS;
				break;
			default:
				return RESULT_ERROR;
		}
		break;
	case	TRG_TILE_GENE_ERROR:
		switch(m_uwTileGenerateParam){
			case TILE_MODE_GENERATE:
				uwNotice = MGR_NOTICE_TILE_GENERATE_ERROR;
				break;
			case TILE_MODE_SPLIT_DISP_ON:
				uwNotice = MGR_NOTICE_TILE_SPLIT_DISP_ERROR;
				break;
			case TILE_MODE_SPLIT_DISP_OFF:
				uwNotice = MGR_NOTICE_SPLIT_DISP_ERASE_ERROR;
				break;
			default:
				return RESULT_ERROR;
		}
		break;
	default:
		return RESULT_ERROR;
	}

	//タイル生成完了通知設定
	VersatileMgrNoticeSet(uwNotice, uwParam);

	return RESULT_SUCCESS;
}

/*******************************************************************************
*	Function Name		：uhwProcReqDispUpdate
*	Description			：表示更新要求処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcReqDispUpdate(void)
{ 
	uhword_type uhwServRet = RESULT_NACK;

	if(m_uhwImageDispReqKind == REQ_DISP_UPDATE_NON){
		//要求なしで本処理が動作した場合エラーを返す
		return RESULT_ERROR;
	}
	
	//メイン画面更新要求の有無確認
	if(m_uhwImageDispReqKind & REQ_DISP_UPDATE_MAIN){
		if(blMapImageReqSelImgConChk()){
			//メイン画面の更新要求を行う
			uhwServRet = m_MapImageReqSelectImageCons->usSetMapImageReqSelectImage(m_stDispUpDateKeyParam.uwMainViewGroupId);
			if(uhwServRet == RESULT_ACK){
				std::cout << "[debug]usSetMapImageReqSelectImage = " << uhwServRet << ", Param = " << m_stDispUpDateKeyParam.uwMainViewGroupId << std::endl;
			}
			else{
				std::cout << "[error]usSetMapImageReqSelectImage = " << uhwServRet << ", Param = " << m_stDispUpDateKeyParam.uwMainViewGroupId << std::endl;
				return RESULT_ERROR;
			}
		}
		else{
			return RESULT_ERROR;
		}
	}

	//サブ画面更新要求の有無確認
	if(m_uhwImageDispReqKind & REQ_DISP_UPDATE_SUB){
		if(blCrawlerViewReqSynthConChk()){
			//サブ画面の更新要求を行う
			uhwServRet = m_CrawlerViewReqSynthesisCons->usSetCrawlerViewReqSynthesis(m_stDispUpDateKeyParam.uwSubViewSelect, m_stDispUpDateKeyParam.uwSubViewGroupId);

			if(uhwServRet == RESULT_ACK){
				std::cout << "[debug]usSetCrawlerViewReqSynthesis = " << uhwServRet << ", Param1 = " << m_stDispUpDateKeyParam.uwSubViewSelect << ", Param2 = " << m_stDispUpDateKeyParam.uwSubViewGroupId << std::endl;
				m_uwSubViewSelect = m_stDispUpDateKeyParam.uwSubViewSelect;
			}
			else{
				std::cout << "[error]usSetCrawlerViewReqSynthesis = " << uhwServRet << ", Param1 = " << m_stDispUpDateKeyParam.uwSubViewSelect << ", Param2 = " << m_stDispUpDateKeyParam.uwSubViewGroupId << std::endl;
				return RESULT_ERROR;
			}
		}
		else{
//一時的にコメント
//			return RESULT_ERROR;
		}
	}

	return RESULT_SUCCESS;
}

/*******************************************************************************
*	Function Name		：uhwProcNoticeDispUpdateEnd
*	Description			：表示更新完了処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcNoticeDispUpdateEnd(void)
{
	uword_type uwNotice = NOTICE_INIT;
	uword_type uwParam = NOTICE_PARAM_INIT;
	bool_type blCompNotice = FALSE;
	uhword_type uhwLoop = 0;
	uhword_type uhwMode = MGR_MODE_NON;

	switch(m_uhwInternalTrg){
	case	TRG_MAP_IMAGE_DISP_SUCCESS:
	case	TRG_MAP_IMAGE_DISP_ERROR:
		//要求をクリア
		if(m_uhwImageDispReqKind & REQ_DISP_UPDATE_MAIN){
			m_uhwImageDispReqKind = (m_uhwImageDispReqKind & MASK_REQ_DISP_UPDATE_MAIN);
		}
		if(m_uhwInternalTrg == TRG_MAP_IMAGE_DISP_ERROR){
			blCompNotice = TRUE;
		}
		break;

	case	TRG_CRAWLER_VIEW_DISP_SUCCESS:
	case	TRG_CRAWLER_VIEW_DISP_ERROR:
		//要求をクリア
		if(m_uhwImageDispReqKind & REQ_DISP_UPDATE_SUB){
			m_uhwImageDispReqKind = (m_uhwImageDispReqKind & MASK_REQ_DISP_UPDATE_SUB);
		}
		if(m_uhwInternalTrg == TRG_CRAWLER_VIEW_DISP_ERROR){
			blCompNotice = TRUE;
		}
		break;

	default:
		return RESULT_ERROR;
	}

	//要求が全てクリアになったあるいは、エラー発生時に完了通知を発行する
	if((blCompNotice == TRUE) || (m_uhwImageDispReqKind == REQ_DISP_UPDATE_NON)){
		for(uhwLoop = 0; uhwLoop < (sizeof(DispUpdateNoticeTbl) / sizeof(DispUpdateNoticeTbl[0])); uhwLoop++){
			if(m_uhwInternalTrg == DispUpdateNoticeTbl[uhwLoop].uhwTrigger){
				uwNotice = DispUpdateNoticeTbl[uhwLoop].uwNotice;
				uhwMode = DispUpdateNoticeTbl[uhwLoop].uhwMode;
				break;
			}
		}

		//表示更新完了通知設定
		VersatileMgrNoticeSet(uwNotice, uwParam);
		//正常終了の場合モードを待機中に遷移させる
		VersatileMgrModeSet(uhwMode);
	}

	return RESULT_SUCCESS;
}

/*******************************************************************************
*	Function Name		：uhwProcNoticeImageOperationEnd
*	Description			：画像操作完了処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcNoticeImageOperationEnd(void)
{
	uword_type uwNotice = NOTICE_INIT;
	uword_type uwParam = NOTICE_PARAM_INIT;

	switch(m_uhwInternalTrg){
		case	TRG_MAP_IMAGE_OPE_SUCCESS:
		case	TRG_MAP_IMAGE_OPE_ERROR:
			if((m_uhwMainDispUpDateSts == MAINDISP_UPDATE_STS_NON) || (m_uhwMainDispUpDateSts >= MAINDISP_UPDATE_STS_MAX)){
				return RESULT_ERROR;
			}
			if(m_uhwInternalTrg == TRG_MAP_IMAGE_OPE_SUCCESS){
				uwNotice = stMainImageNoticeTbl[m_uhwMainDispUpDateSts]->uwNoticeSuccess;
			}
			else{
				uwNotice = stMainImageNoticeTbl[m_uhwMainDispUpDateSts]->uwNoticeError;
			}
			m_uhwMainDispUpDateSts = MAINDISP_UPDATE_STS_NON;
			break;

		case	TRG_CRAWLER_VIEW_OPE_SUCCESS:
		case	TRG_CRAWLER_VIEW_OPE_ERROR:
			if((m_uhwSubDispUpDateSts == SUBDISP_UPDATE_STS_NON) || (m_uhwSubDispUpDateSts >= SUBDISP_UPDATE_STS_MAX)){
				return RESULT_ERROR;
			}

			if(m_uhwInternalTrg == TRG_CRAWLER_VIEW_OPE_SUCCESS){
				uwNotice = stSubImageNoticeTbl[m_uhwSubDispUpDateSts]->uwNoticeSuccess;
			}
			else{
				uwNotice = stSubImageNoticeTbl[m_uhwSubDispUpDateSts]->uwNoticeError;
			}
			m_uhwSubDispUpDateSts = SUBDISP_UPDATE_STS_NON;
			break;

		default:
			return RESULT_ERROR;
	}

	//表示更新完了通知設定
	VersatileMgrNoticeSet(uwNotice, uwParam);

	return RESULT_SUCCESS;
}

/*******************************************************************************
*	Function Name		：uhwProcReqSyntheListDel
*	Description			：合成計画リスト削除要求処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcReqSyntheListDel(void)
{
	uhword_type uhwRet = RESULT_ERROR;
	uhword_type uhwServRet = RESULT_NACK;

	//サービスポート接続確認
	if(blMapDBReqDelSynthListConChk()){
		uhwServRet = m_MapDBReqDelSynthesisPlanListCons->usSetMapDBReqDelSynthesisPlanList(m_uwSyntheListDelParam);
		if(uhwServRet == RESULT_ACK){
			std::cout << "[debug]usSetMapDBReqDelSynthesisPlanList = " << uhwServRet << ", Param = " << m_uwSyntheListDelParam << std::endl;
			uhwRet = RESULT_SUCCESS;
		}else{
			std::cout << "[error]usSetMapDBReqDelSynthesisPlanList = " << uhwServRet << ", Param = " << m_uwSyntheListDelParam << std::endl;
			uhwRet = RESULT_ERROR;
		}
	}
	return uhwRet;
}

/*******************************************************************************
*	Function Name		：uhwProcNoticeSyntheListDelEnd
*	Description			：合成計画リスト削除完了通知処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcNoticeSyntheListDelEnd(void)
{ 
	uhword_type uhwRet = RESULT_ERROR;
	uhword_type uhwServRet = RESULT_NACK;
	uword_type uwNotice = NOTICE_INIT;
	uword_type uwParam = NOTICE_PARAM_INIT;

	switch(m_uhwInternalTrg){
	case	TRG_SYNTHE_LIST_DEL_SUCCESS:
		uwNotice = MGR_NOTICE_SYNTHE_LIST_DEL_SUCCESS;
		uwParam = m_uwMapDBParam;
		break;
	case	TRG_SYNTHE_LIST_DEL_ERROR:
		uwNotice = MGR_NOTICE_SYNTHE_LIST_DEL_ERROR;
		uwParam = m_uwMapDBParam;
		break;
	default:
		return RESULT_ERROR;
	}

	//合成計画リスト削除完了通知設定
	VersatileMgrNoticeSet(uwNotice, uwParam);

	return RESULT_SUCCESS;
}

/*******************************************************************************
*	Function Name		：uhwProcReqArrow
*	Description			：十字キー操作要求処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcReqArrow(void)
{
	uhword_type uhwServRet = RESULT_NACK;

	if(m_uwOpeScreen == OPE_SCREEN_SUB){
		if((m_uwArrowParam == ARROW_UP) || (m_uwArrowParam == ARROW_DOWN)){
			if(blCrawlerViewReqSlideConChk()){
				uhwServRet = m_CrawlerViewReqSlideCons->usSetCrawlerViewReqSlide(m_uwArrowParam);
				if(uhwServRet == RESULT_ACK){
					std::cout << "[debug]usSetCrawlerViewReqSlide = " << uhwServRet << ", Param = " << m_uwArrowParam << std::endl;
					m_uhwSubDispUpDateSts = SUBDISP_UPDATE_STS_SLIDE;
				}
				else{
					std::cout << "[error]usSetCrawlerViewReqSlide = " << uhwServRet << ", Param = " << m_uwArrowParam << std::endl;
					return RESULT_ERROR;
				}
			}
			else{
//一時的に何もしない
//					return RESULT_ERROR;
			}
		}else{
			std::cout << "[error]uhwProcReqArrow():m_uwSubViewSelect = " << m_uwSubViewSelect << std::endl;
			return RESULT_ERROR;
		}

	}
	else{
		if(blMapImageReqScrollConChk()){
			uhwServRet = m_MapImageReqScrollCons->usSetMapImageReqScroll(m_uwArrowParam);
			if(uhwServRet == RESULT_ACK){
				std::cout << "[debug]usSetMapImageReqScroll = " << uhwServRet << ", Param = " << m_uwArrowParam << std::endl;
				m_uhwMainDispUpDateSts = MAINDISP_UPDATE_STS_MAP_SCROLL;
			}
			else{
				std::cout << "[error]usSetMapImageReqScroll = " << uhwServRet << ", Param = " << m_uwArrowParam << std::endl;
				return RESULT_ERROR;
			}
		}
		else{
			return RESULT_ERROR;
		}
	}

	return RESULT_SUCCESS;
}

/*******************************************************************************
*	Function Name		：uhwProcReqZoom
*	Description			：ズームレベル調整キー要求処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcReqZoom(void)
{
	uhword_type uhwServRet = RESULT_NACK;
	uhword_type uhwRet = RESULT_ERROR;

	//サービスポート接続確認
	if(blMapImageReqAdjZoomConChk()){
		uhwServRet = m_MapImageReqAdjZoomCons->usSetMapImageReqAdjZoom(m_uwZoomParam);
		if(uhwServRet == RESULT_ACK){
			std::cout << "[debug]usSetMapImageReqAdjZoom = " << uhwServRet << ", Param = " << m_uwZoomParam << std::endl;
			m_uhwMainDispUpDateSts = MAINDISP_UPDATE_STS_MAP_ZOOM;
			uhwRet = RESULT_SUCCESS;
		}else{
			std::cout << "[error]usSetMapImageReqAdjZoom = " << uhwServRet << ", Param = " << m_uwZoomParam << std::endl;
		}
	}

	return uhwRet;
}

/*******************************************************************************
*	Function Name		：uhwProcReqMapChange
*	Description			：地図切り替え要求処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcReqMapChange(void)
{
	uhword_type uhwServRet = RESULT_NACK;
	uhword_type uhwRet = RESULT_ERROR;

	//サービスポート接続確認
	if(blMapImageReqAdjMapChgConChk()){
		uhwServRet = m_MapImageReqAdjMapChangeCons->usSetMapImageReqAdjMapChange(m_uwMapChgParam);
		if(uhwServRet == RESULT_ACK){
			std::cout << "[debug]usSetMapImageReqAdjMapChange = " << uhwServRet << ", Param = " << m_uwMapChgParam << std::endl;
			m_uhwMainDispUpDateSts = MAINDISP_UPDATE_STS_MAP_CHG;
			uhwRet = RESULT_SUCCESS;
		}else{
			std::cout << "[error]usSetMapImageReqAdjMapChange = " << uhwServRet << ", Param = " << m_uwMapChgParam << std::endl;
		}
	}

	return uhwRet;
}

/*******************************************************************************
*	Function Name		：uhwProcInitWarningMessage
*	Description			：初回起動中の操作抑止警告処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcInitWarningMessage(void)
{
	VersatileMgrNoticeSet(MGR_NOTICE_INIT_WARNING, NOTICE_PARAM_INIT);
	std::cout << ERROR_MESSEGE_1 << std::endl;

	return RESULT_SUCCESS;
}

/*******************************************************************************
*	Function Name		：uhwProcRunWarningMessage
*	Description			：動作中の操作抑止警告処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcRunWarningMessage(void)
{
	VersatileMgrNoticeSet(MGR_NOTICE_RUN_WARNING, NOTICE_PARAM_INIT);
	std::cout << ERROR_MESSEGE_2 << std::endl;

	return RESULT_SUCCESS;
}

/*******************************************************************************
*	Function Name		：uhwProcErrorMessage
*	Description			：エラー中の操作抑止警告処理
*	Argument			：なし
*	Return				：正常終了/異常終了
*******************************************************************************/
uhword_type VersatileOverheadManager::uhwProcErrorMessage(void)
{
	VersatileMgrNoticeSet(MGR_NOTICE_ERROR, NOTICE_PARAM_INIT);
	std::cout << ERROR_MESSEGE_3 << std::endl;

	return RESULT_SUCCESS;
}

/******************************************************************************************
	使用サービスポートの接続確認処理
******************************************************************************************/
/******************************************************************************************
*	Function Name		：blGuiReqDBRegistKeyConChk
*	Description			：DB登録キー押下要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blGuiReqDBRegistKeyConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_GuiReqDBRegistKeyCons._ptr())){
			std::cout << "[nil]m_GuiReqDBRegistKeyCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_GuiReqDBRegistKeyCons->_non_existent()){
				std::cout << "[inactive]m_GuiReqDBRegistKeyCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blGuiReqSynthListDelKeyConChk
*	Description			：合成計画リスト削除キー押下要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blGuiReqSynthListDelKeyConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_GuiReqSynthesisPlanListDelKeyCons._ptr())){
			std::cout << "[nil]m_GuiReqSynthesisPlanListDelKeyCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_GuiReqSynthesisPlanListDelKeyCons->_non_existent()){
				std::cout << "[inactive]m_GuiReqSynthesisPlanListDelKeyCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blGuiReqTileGeneKeyConChk
*	Description			：タイル生成キー押下要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blGuiReqTileGeneKeyConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_GuiReqTileGenerationKeyCons._ptr())){
			std::cout << "[nil]m_GuiReqTileGenerationKeyCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_GuiReqTileGenerationKeyCons->_non_existent()){
				std::cout << "[inactive]m_GuiReqTileGenerationKeyCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blGuiReqDispUpdateKeyConChk
*	Description			：表示更新キー押下要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blGuiReqDispUpdateKeyConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_GuiReqDisplayUpdateKeyCons._ptr())){
			std::cout << "[nil]m_GuiReqDisplayUpdateKeyCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_GuiReqDisplayUpdateKeyCons->_non_existent()){
				std::cout << "[inactive]m_GuiReqDisplayUpdateKeyCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blGuiReqArrowKeyConChk
*	Description			：十字キー押下要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blGuiReqArrowKeyConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_GuiReqArrowKeyCons._ptr())){
			std::cout << "[nil]m_GuiReqArrowKeyCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_GuiReqArrowKeyCons->_non_existent()){
				std::cout << "[inactive]m_GuiReqArrowKeyCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blGuiReqZoomKeyConChk
*	Description			：ズームレベル調整キー押下要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blGuiReqZoomKeyConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_GuiReqZoomKeyCons._ptr())){
			std::cout << "[nil]m_GuiReqZoomKeyCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_GuiReqZoomKeyCons->_non_existent()){
				std::cout << "[inactive]m_GuiReqZoomKeyCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blGuiReqMapChangeKeyConChk
*	Description			：地図切り替えキー押下要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blGuiReqMapChangeKeyConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_GuiReqMapChangeKeyCons._ptr())){
			std::cout << "[nil]m_GuiReqMapChangeKeyCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_GuiReqMapChangeKeyCons->_non_existent()){
				std::cout << "[inactive]m_GuiReqMapChangeKeyCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blAddDBReqRegistAddDataConChk
*	Description			：DB登録要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blAddDBReqRegistAddDataConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_AddDBReqRegistAddDataCons._ptr())){
			std::cout << "[nil]m_AddDBReqRegistAddDataCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_AddDBReqRegistAddDataCons->_non_existent()){
				std::cout << "[inactive]m_AddDBReqRegistAddDataCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blAddDBReqMakeShootListConChk
*	Description			：撮影計画リスト作成要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blAddDBReqMakeShootListConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_AddDBReqMakeShootingPlanListCons._ptr())){
			std::cout << "[nil]m_AddDBReqMakeShootingPlanListCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_AddDBReqMakeShootingPlanListCons->_non_existent()){
				std::cout << "[inactive]m_AddDBReqMakeShootingPlanListCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blAddDBReqGetShootListConChk
*	Description			：撮影計画リスト取得要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blAddDBReqGetShootListConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_AddDBReqGetShootingPlanListCons._ptr())){
			std::cout << "[nil]m_AddDBReqGetShootingPlanListCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_AddDBReqGetShootingPlanListCons->_non_existent()){
				std::cout << "[inactive]m_AddDBReqGetShootingPlanListCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blAddDBNoticeConChk
*	Description			：画像付加DB制御コンポーネント完了通知用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blAddDBNoticeConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_AddDBNoticeCons._ptr())){
			std::cout << "[nil]m_AddDBNoticeCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_AddDBNoticeCons->_non_existent()){
				std::cout << "[inactive]m_AddDBNoticeCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blTileGeneReqMakeTileConChk
*	Description			：タイル生成要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blTileGeneReqMakeTileConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_TileGenerateReqMakeTileCons._ptr())){
			std::cout << "[nil]m_TileGenerateReqMakeTileCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_TileGenerateReqMakeTileCons->_non_existent()){
				std::cout << "[inactive]m_TileGenerateReqMakeTileCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blTileGeneStsConChk
*	Description			：タイル生成コンポーネント完了通知用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blTileGeneNoticeConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_TileGenerateNoticeCons._ptr())){
			std::cout << "[nil]m_TileGenerateNoticeCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_TileGenerateNoticeCons->_non_existent()){
				std::cout << "[inactive]m_TileGenerateNoticeCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blMapDBReqRegistAddDataConChk
*	Description			：地図データDB登録要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blMapDBReqRegistAddDataConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_MapDBReqRegistAddDataCons._ptr())){
			std::cout << "[nil]m_MapDBReqRegistAddDataCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_MapDBReqRegistAddDataCons->_non_existent()){
				std::cout << "[inactive]m_MapDBReqRegistAddDataCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blMapDBReqMakeSynthListConChk
*	Description			：合成計画リスト作成要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blMapDBReqMakeSynthListConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_MapDBReqMakeSynthesisPlanListCons._ptr())){
			std::cout << "[nil]m_MapDBReqMakeSynthesisPlanListCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_MapDBReqMakeSynthesisPlanListCons->_non_existent()){
				std::cout << "[inactive]m_MapDBReqMakeSynthesisPlanListCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blMapDBReqGetSynthListConChk
*	Description			：合成計画リスト取得要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blMapDBReqGetSynthListConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_MapDBReqGetSynthesisPlanListCons._ptr())){
			std::cout << "[nil]m_MapDBReqGetSynthesisPlanListCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_MapDBReqGetSynthesisPlanListCons->_non_existent()){
				std::cout << "[inactive]m_MapDBReqGetSynthesisPlanListCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blMapDBReqDelSynthListConChk
*	Description			：合成計画リスト削除要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blMapDBReqDelSynthListConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_MapDBReqDelSynthesisPlanListCons._ptr())){
			std::cout << "[nil]m_MapDBReqDelSynthesisPlanListCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_MapDBReqDelSynthesisPlanListCons->_non_existent()){
				std::cout << "[inactive]m_MapDBReqDelSynthesisPlanListCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blMapDataDBNoticeConChk
*	Description			：地図データDB制御コンポーネント完了通知用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blMapDataDBNoticeConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_MapDataDBNoticeCons._ptr())){
			std::cout << "[nil]m_MapDataDBNoticeCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_MapDataDBNoticeCons->_non_existent()){
				std::cout << "[inactive]m_MapDataDBNoticeCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blMapImageReqSelImgConChk
*	Description			：表示更新要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blMapImageReqSelImgConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_MapImageReqSelectImageCons._ptr())){
			std::cout << "[nil]m_MapImageReqSelectImageCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_MapImageReqSelectImageCons->_non_existent()){
				std::cout << "[inactive]m_MapImageReqSelectImageCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blMapImageReqScrollConChk
*	Description			：地図スクロール要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blMapImageReqScrollConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_MapImageReqScrollCons._ptr())){
			std::cout << "[nil]m_MapImageReqScrollCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_MapImageReqScrollCons->_non_existent()){
				std::cout << "[inactive]m_MapImageReqScrollCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blMapImageReqAdjZoomConChk
*	Description			：ズームレベル調整キー要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blMapImageReqAdjZoomConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_MapImageReqAdjZoomCons._ptr())){
			std::cout << "[nil]m_MapImageReqAdjZoomCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_MapImageReqAdjZoomCons->_non_existent()){
				std::cout << "[inactive]m_MapImageReqAdjZoomCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：uhwProcReqMapChange
*	Description			：地図切り替え要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blMapImageReqAdjMapChgConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_MapImageReqAdjMapChangeCons._ptr())){
			std::cout << "[nil]m_MapImageReqAdjMapChangeCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_MapImageReqAdjMapChangeCons->_non_existent()){
				std::cout << "[inactive]m_MapImageReqAdjMapChangeCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blMapImageNoticeConChk
*	Description			：地図画像セレクトコンポーネント完了通知用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blMapImageNoticeConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_MapImageNoticeCons._ptr())){
			std::cout << "[nil]m_MapImageNoticeCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_MapImageNoticeCons->_non_existent()){
				std::cout << "[inactive]m_MapImageNoticeCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blCrawlerViewReqSynthConChk
*	Description			：Crawler View表示更新要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blCrawlerViewReqSynthConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_CrawlerViewReqSynthesisCons._ptr())){
			std::cout << "[nil]m_CrawlerViewReqSynthesisCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_CrawlerViewReqSynthesisCons->_non_existent()){
				std::cout << "[inactive]m_CrawlerViewReqSynthesisCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blCrawlerViewReqSlideConChk
*	Description			：スライド切り替え要求用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blCrawlerViewReqSlideConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_CrawlerViewReqSlideCons._ptr())){
			std::cout << "[nil]m_CrawlerViewReqSlideCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_CrawlerViewReqSlideCons->_non_existent()){
				std::cout << "[inactive]m_CrawlerViewReqSlideCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/******************************************************************************************
*	Function Name		：blCrawlerViewNoticeConChk
*	Description			：Crawler Viewコンポーネント完了通知用のサービスポート接続確認
*	Argument			：なし
*	Return				：接続正常/接続異常
******************************************************************************************/
bool_type VersatileOverheadManager::blCrawlerViewNoticeConChk(void)
{
	bool_type ret = TRUE;

	try{
		if(CORBA::is_nil(m_CrawlerViewNoticeCons._ptr())){
			std::cout << "[nil]m_CrawlerViewNoticeCons is not assigned" << std::endl;
			return FALSE;
		}else{
			if(m_CrawlerViewNoticeCons->_non_existent()){
				std::cout << "[inactive]m_CrawlerViewNoticeCons is inactive" << std::endl;
				return FALSE;
			}else{
				//サービスポート接続正常
			}
		}
	}
	catch(...){
		std::cout << "[error]Unknown exception" << std::endl;
		return FALSE;
	}

	return ret;
}

/*****************************************************************************************
*	Function Name		：VersatileMgrModeSet
*	Description			：マトリクスモード更新処理
*	Argument			：更新モード
*	Return				：なし
******************************************************************************************/
void VersatileOverheadManager::VersatileMgrModeSet(uhword_type uhwMode)
{
	m_uhwInternalMode = uhwMode;
	m_VersatileMgrStsProv.usSetVersatileMgrSts(m_uhwInternalMode);
	std::cout << "[debug]Matrix Mode = " << m_uhwInternalMode << std::endl;
}

/*****************************************************************************************
*	Function Name		：VersatileMgrNoticeSet
*	Description			：完了通知更新処理
*	Argument			：完了通知、パラメータ
*	Return				：なし
******************************************************************************************/
void VersatileOverheadManager::VersatileMgrNoticeSet(uword_type uwNotice, uword_type uwParam)
{
	m_VersatileMgrCompNoticeProv.usSetVersatileMgrCompNotice(uwNotice, uwParam);
	std::cout << "[debug]usSetVersatileMgrCompNotice()" << ",param1 = " << uwNotice << ",param2 = " << uwParam << std::endl;
}


extern "C"
{
 
  void VersatileOverheadManagerInit(RTC::Manager* manager)
  {
    coil::Properties profile(versatileoverheadmanager_spec);
    manager->registerFactory(profile,
                             RTC::Create<VersatileOverheadManager>,
                             RTC::Delete<VersatileOverheadManager>);
  }
  
};


